@@ -34,7 +34,10 @@ void iRel_getErrorType( iRel_Instance instance, int* error_type )
 
 void iRel_getDescription( iRel_Instance instance, char* descr, int descr_len )
 {
-    if( instance == NULL ) { strcpy( descr, "iRel_getDescription: Invalid instance" ); }
+    if( instance == NULL )
+    {
+        strcpy( descr, "iRel_getDescription: Invalid instance" );
+    }
     else
     {
         unsigned int len = std::min( strlen( LASSOI->lastErrorDescription ), static_cast< size_t >( descr_len ) );
@@ -61,9 +64,17 @@ void iRel_destroy( iRel_Instance instance, int* err )
     *err = iBase_SUCCESS;
 }
 
-void iRel_createPair( iRel_Instance instance, iBase_Instance iface1, const int ent_or_set1, const int iface_type1,
-                      const int irel_status1, iBase_Instance iface2, const int ent_or_set2, const int iface_type2,
-                      const int irel_status2, iRel_PairHandle* pair, int* err )
+void iRel_createPair( iRel_Instance instance,
+                      iBase_Instance iface1,
+                      const int ent_or_set1,
+                      const int iface_type1,
+                      const int irel_status1,
+                      iBase_Instance iface2,
+                      const int ent_or_set2,
+                      const int iface_type2,
+                      const int irel_status2,
+                      iRel_PairHandle* pair,
+                      int* err )
 {
     AssocPair* assoc_pair = new AssocPair(
         instance, iface1, static_cast< iRel_RelationType >( ent_or_set1 ), static_cast< iRel_IfaceType >( iface_type1 ),
@@ -75,9 +86,17 @@ void iRel_createPair( iRel_Instance instance, iBase_Instance iface1, const int e
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_getPairInfo( iRel_Instance instance, iRel_PairHandle pair, iBase_Instance* iface1, int* ent_or_set1,
-                       int* iface_type1, int* irel_status1, iBase_Instance* iface2, int* ent_or_set2, int* iface_type2,
-                       int* irel_status2, int* err )
+void iRel_getPairInfo( iRel_Instance instance,
+                       iRel_PairHandle pair,
+                       iBase_Instance* iface1,
+                       int* ent_or_set1,
+                       int* iface_type1,
+                       int* irel_status1,
+                       iBase_Instance* iface2,
+                       int* ent_or_set2,
+                       int* iface_type2,
+                       int* irel_status2,
+                       int* err )
 {
     CHK_PAIR();
 
@@ -114,8 +133,12 @@ void iRel_destroyPair( iRel_Instance instance, iRel_PairHandle pair, int* err )
     CHK_ERROR( LASSOI->erase_pair( ASSOCPAIRI ) );
 }
 
-void iRel_findPairs( iRel_Instance instance, iBase_Instance iface, iRel_PairHandle** pairs, int* pairs_allocated,
-                     int* pairs_size, int* err )
+void iRel_findPairs( iRel_Instance instance,
+                     iBase_Instance iface,
+                     iRel_PairHandle** pairs,
+                     int* pairs_allocated,
+                     int* pairs_size,
+                     int* err )
 {
     std::vector< AssocPair* > tmp_pairs;
     LASSOI->find_pairs( iface, tmp_pairs );
@@ -129,32 +152,49 @@ void iRel_findPairs( iRel_Instance instance, iBase_Instance iface, iRel_PairHand
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_setEntEntRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle ent1,
-                             iBase_EntityHandle ent2, int* err )
+void iRel_setEntEntRelation( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntityHandle ent1,
+                             iBase_EntityHandle ent2,
+                             int* err )
 {
     CHK_PAIR();CHK_ERROR( ASSOCPAIRI->set_relation( ent1, ent2 ) );
 }
 
-void iRel_setEntSetRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle ent1,
-                             iBase_EntitySetHandle set2, int* err )
+void iRel_setEntSetRelation( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntityHandle ent1,
+                             iBase_EntitySetHandle set2,
+                             int* err )
 {
     CHK_PAIR();CHK_ERROR( ASSOCPAIRI->set_relation( ent1, set2 ) );
 }
 
-void iRel_setSetEntRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle set1,
-                             iBase_EntityHandle ent2, int* err )
+void iRel_setSetEntRelation( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntitySetHandle set1,
+                             iBase_EntityHandle ent2,
+                             int* err )
 {
     CHK_PAIR();CHK_ERROR( ASSOCPAIRI->set_relation( set1, ent2 ) );
 }
 
-void iRel_setSetSetRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle set1,
-                             iBase_EntitySetHandle set2, int* err )
+void iRel_setSetSetRelation( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntitySetHandle set1,
+                             iBase_EntitySetHandle set2,
+                             int* err )
 {
     CHK_PAIR();CHK_ERROR( ASSOCPAIRI->set_relation( set1, set2 ) );
 }
 
-void iRel_setEntArrEntArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* ent_array_1,
-                                   int num_entities1, iBase_EntityHandle* ent_array_2, int num_entities2, int* err )
+void iRel_setEntArrEntArrRelation( iRel_Instance instance,
+                                   iRel_PairHandle pair,
+                                   iBase_EntityHandle* ent_array_1,
+                                   int num_entities1,
+                                   iBase_EntityHandle* ent_array_2,
+                                   int num_entities2,
+                                   int* err )
 {
     CHK_PAIR();
 
@@ -178,8 +218,13 @@ void iRel_setEntArrEntArrRelation( iRel_Instance instance, iRel_PairHandle pair,
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_setEntArrSetArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* ent_array_1,
-                                   int num_entities1, iBase_EntitySetHandle* set_array_2, int num_sets2, int* err )
+void iRel_setEntArrSetArrRelation( iRel_Instance instance,
+                                   iRel_PairHandle pair,
+                                   iBase_EntityHandle* ent_array_1,
+                                   int num_entities1,
+                                   iBase_EntitySetHandle* set_array_2,
+                                   int num_sets2,
+                                   int* err )
 {
     CHK_PAIR();
 
@@ -203,8 +248,13 @@ void iRel_setEntArrSetArrRelation( iRel_Instance instance, iRel_PairHandle pair,
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_setSetArrEntArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle* set_array_1,
-                                   int num_sets1, iBase_EntityHandle* ent_array_2, int num_entities2, int* err )
+void iRel_setSetArrEntArrRelation( iRel_Instance instance,
+                                   iRel_PairHandle pair,
+                                   iBase_EntitySetHandle* set_array_1,
+                                   int num_sets1,
+                                   iBase_EntityHandle* ent_array_2,
+                                   int num_entities2,
+                                   int* err )
 {
     CHK_PAIR();
 
@@ -228,8 +278,13 @@ void iRel_setSetArrEntArrRelation( iRel_Instance instance, iRel_PairHandle pair,
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_setSetArrSetArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle* set_array_1,
-                                   int num_sets1, iBase_EntitySetHandle* set_array_2, int num_sets2, int* err )
+void iRel_setSetArrSetArrRelation( iRel_Instance instance,
+                                   iRel_PairHandle pair,
+                                   iBase_EntitySetHandle* set_array_1,
+                                   int num_sets1,
+                                   iBase_EntitySetHandle* set_array_2,
+                                   int num_sets2,
+                                   int* err )
 {
     CHK_PAIR();
 
@@ -253,49 +308,75 @@ void iRel_setSetArrSetArrRelation( iRel_Instance instance, iRel_PairHandle pair,
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_getEntEntRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle ent1, int switch_order,
-                             iBase_EntityHandle* ent2, int* err )
+void iRel_getEntEntRelation( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntityHandle ent1,
+                             int switch_order,
+                             iBase_EntityHandle* ent2,
+                             int* err )
 {
     CHK_PAIR();
 
     int iface_no = ( switch_order ? 1 : 0 );CHK_ERROR( ASSOCPAIRI->get_relation( iface_no, &ent1, 1, ent2 ) );
 }
 
-void iRel_getEntSetRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle ent1, int switch_order,
-                             iBase_EntitySetHandle* set2, int* err )
+void iRel_getEntSetRelation( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntityHandle ent1,
+                             int switch_order,
+                             iBase_EntitySetHandle* set2,
+                             int* err )
 {
     CHK_PAIR();
 
     int iface_no = ( switch_order ? 1 : 0 );CHK_ERROR( ASSOCPAIRI->get_relation( iface_no, &ent1, 1, set2 ) );
 }
 
-void iRel_getSetEntRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle set1, int switch_order,
-                             iBase_EntityHandle* ent2, int* err )
+void iRel_getSetEntRelation( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntitySetHandle set1,
+                             int switch_order,
+                             iBase_EntityHandle* ent2,
+                             int* err )
 {
     CHK_PAIR();
 
     int iface_no = ( switch_order ? 1 : 0 );CHK_ERROR( ASSOCPAIRI->get_relation( iface_no, &set1, 1, ent2 ) );
 }
 
-void iRel_getSetSetRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle set1, int switch_order,
-                             iBase_EntitySetHandle* set2, int* err )
+void iRel_getSetSetRelation( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntitySetHandle set1,
+                             int switch_order,
+                             iBase_EntitySetHandle* set2,
+                             int* err )
 {
     CHK_PAIR();
 
     int iface_no = ( switch_order ? 1 : 0 );CHK_ERROR( ASSOCPAIRI->get_relation( iface_no, &set1, 1, set2 ) );
 }
 
-void iRel_getEntSetIterRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle ent1,
-                                 int switch_order, iBase_EntityIterator* entset2, int* err )
+void iRel_getEntSetIterRelation( iRel_Instance instance,
+                                 iRel_PairHandle pair,
+                                 iBase_EntityHandle ent1,
+                                 int switch_order,
+                                 iBase_EntityIterator* entset2,
+                                 int* err )
 {
     CHK_PAIR();
 
     int iface_no = ( switch_order ? 1 : 0 );CHK_ERROR( ASSOCPAIRI->get_relation( iface_no, &ent1, 1, entset2 ) );
 }
 
-void iRel_getEntArrEntArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* ent_array_1,
-                                   int ent_array_1_size, int switch_order, iBase_EntityHandle** ent_array_2,
-                                   int* ent_array_2_allocated, int* ent_array_2_size, int* err )
+void iRel_getEntArrEntArrRelation( iRel_Instance instance,
+                                   iRel_PairHandle pair,
+                                   iBase_EntityHandle* ent_array_1,
+                                   int ent_array_1_size,
+                                   int switch_order,
+                                   iBase_EntityHandle** ent_array_2,
+                                   int* ent_array_2_allocated,
+                                   int* ent_array_2_size,
+                                   int* err )
 {
     CHK_PAIR();
 
@@ -306,9 +387,15 @@ void iRel_getEntArrEntArrRelation( iRel_Instance instance, iRel_PairHandle pair,
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_getEntArrSetArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* ent_array_1,
-                                   int ent_array_1_size, int switch_order, iBase_EntitySetHandle** set_array_2,
-                                   int* set_array_2_allocated, int* set_array_2_size, int* err )
+void iRel_getEntArrSetArrRelation( iRel_Instance instance,
+                                   iRel_PairHandle pair,
+                                   iBase_EntityHandle* ent_array_1,
+                                   int ent_array_1_size,
+                                   int switch_order,
+                                   iBase_EntitySetHandle** set_array_2,
+                                   int* set_array_2_allocated,
+                                   int* set_array_2_size,
+                                   int* err )
 {
     CHK_PAIR();
 
@@ -319,9 +406,15 @@ void iRel_getEntArrSetArrRelation( iRel_Instance instance, iRel_PairHandle pair,
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_getSetArrEntArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle* set_array_1,
-                                   int set_array_1_size, int switch_order, iBase_EntityHandle** ent_array_2,
-                                   int* ent_array_2_allocated, int* ent_array_2_size, int* err )
+void iRel_getSetArrEntArrRelation( iRel_Instance instance,
+                                   iRel_PairHandle pair,
+                                   iBase_EntitySetHandle* set_array_1,
+                                   int set_array_1_size,
+                                   int switch_order,
+                                   iBase_EntityHandle** ent_array_2,
+                                   int* ent_array_2_allocated,
+                                   int* ent_array_2_size,
+                                   int* err )
 {
     CHK_PAIR();
 
@@ -332,9 +425,15 @@ void iRel_getSetArrEntArrRelation( iRel_Instance instance, iRel_PairHandle pair,
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_getSetArrSetArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle* set_array_1,
-                                   int set_array_1_size, int switch_order, iBase_EntitySetHandle** set_array_2,
-                                   int* set_array_2_allocated, int* set_array_2_size, int* err )
+void iRel_getSetArrSetArrRelation( iRel_Instance instance,
+                                   iRel_PairHandle pair,
+                                   iBase_EntitySetHandle* set_array_1,
+                                   int set_array_1_size,
+                                   int switch_order,
+                                   iBase_EntitySetHandle** set_array_2,
+                                   int* set_array_2_allocated,
+                                   int* set_array_2_size,
+                                   int* err )
 {
     CHK_PAIR();
 
@@ -345,9 +444,15 @@ void iRel_getSetArrSetArrRelation( iRel_Instance instance, iRel_PairHandle pair,
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_getEntArrSetIterArrRelation( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* ent_array_1,
-                                       int ent_array_1_size, int switch_order, iBase_EntityIterator** entiter,
-                                       int* entiter_allocated, int* entiter_size, int* err )
+void iRel_getEntArrSetIterArrRelation( iRel_Instance instance,
+                                       iRel_PairHandle pair,
+                                       iBase_EntityHandle* ent_array_1,
+                                       int ent_array_1_size,
+                                       int switch_order,
+                                       iBase_EntityIterator** entiter,
+                                       int* entiter_allocated,
+                                       int* entiter_size,
+                                       int* err )
 {
     CHK_PAIR();
 
@@ -405,8 +510,13 @@ void iRel_rmvSetArrRelation( iRel_Instance instance,
     int iface_no = ( switch_order ? 1 : 0 );CHK_ERROR( ASSOCPAIRI->rmv_relation( iface_no, entset_array, num_ent ) );
 }
 
-static int get_gids_and_dims( iRel_PairHandle pair, int iface_no, iBase_EntityHandle* ents, int ents_size,
-                              int ent_or_set, std::vector< int >& ents_gids, std::vector< int >& ents_dims )
+static int get_gids_and_dims( iRel_PairHandle pair,
+                              int iface_no,
+                              iBase_EntityHandle* ents,
+                              int ents_size,
+                              int ent_or_set,
+                              std::vector< int >& ents_gids,
+                              std::vector< int >& ents_dims )
 {
     int result;
     iBase_EntitySetHandle* sets = reinterpret_cast< iBase_EntitySetHandle* >( ents );
@@ -437,9 +547,15 @@ static int get_gids_and_dims( iRel_PairHandle pair, int iface_no, iBase_EntityHa
     return iBase_SUCCESS;
 }
 
-static void iRel_inferArrArrRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* ents1,
-                                       const int ents1_size, int ent_or_set1, iBase_EntityHandle* ents2,
-                                       const int ents2_size, int ent_or_set2, int* err )
+static void iRel_inferArrArrRelations( iRel_Instance instance,
+                                       iRel_PairHandle pair,
+                                       iBase_EntityHandle* ents1,
+                                       const int ents1_size,
+                                       int ent_or_set1,
+                                       iBase_EntityHandle* ents2,
+                                       const int ents2_size,
+                                       int ent_or_set2,
+                                       int* err )
 {
     int result;
 
@@ -474,7 +590,7 @@ static void iRel_inferArrArrRelations( iRel_Instance instance, iRel_PairHandle p
             }
             else if( ent_or_set1 != iRel_ENTITY && ent_or_set2 == iRel_ENTITY )
             {
-                result = ASSOCPAIRI->set_relation( ( iBase_EntitySetHandle )( *iter ).second, ents2[i] );
+                result = ASSOCPAIRI->set_relation( (iBase_EntitySetHandle)( *iter ).second, ents2[i] );
             }
             else if( ent_or_set1 == iRel_ENTITY && ent_or_set2 != iRel_ENTITY )
             {
@@ -482,7 +598,7 @@ static void iRel_inferArrArrRelations( iRel_Instance instance, iRel_PairHandle p
             }
             else
             {  // ent_or_set1 != iRel_ENTITY && ent_or_set2 != iRel_ENTITY
-                result = ASSOCPAIRI->set_relation( ( iBase_EntitySetHandle )( *iter ).second,
+                result = ASSOCPAIRI->set_relation( (iBase_EntitySetHandle)( *iter ).second,
                                                    (iBase_EntitySetHandle)ents2[i] );
             }
 
@@ -493,28 +609,48 @@ static void iRel_inferArrArrRelations( iRel_Instance instance, iRel_PairHandle p
     RETURN( iBase_SUCCESS );
 }
 
-void iRel_inferEntArrEntArrRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* ents1,
-                                      const int ents1_size, iBase_EntityHandle* ents2, const int ents2_size, int* err )
+void iRel_inferEntArrEntArrRelations( iRel_Instance instance,
+                                      iRel_PairHandle pair,
+                                      iBase_EntityHandle* ents1,
+                                      const int ents1_size,
+                                      iBase_EntityHandle* ents2,
+                                      const int ents2_size,
+                                      int* err )
 {
     iRel_inferArrArrRelations( instance, pair, ents1, ents1_size, 0, ents2, ents2_size, 0, err );
 }
 
-void iRel_inferEntArrSetArrRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* ents1,
-                                      const int ents1_size, iBase_EntitySetHandle* ents2, const int ents2_size,
+void iRel_inferEntArrSetArrRelations( iRel_Instance instance,
+                                      iRel_PairHandle pair,
+                                      iBase_EntityHandle* ents1,
+                                      const int ents1_size,
+                                      iBase_EntitySetHandle* ents2,
+                                      const int ents2_size,
                                       int* err )
 {
     iRel_inferArrArrRelations( instance, pair, ents1, ents1_size, 0, (iBase_EntityHandle*)ents2, ents2_size, 1, err );
 }
 
-void iRel_inferSetArrEntArrRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle* ents1,
-                                      const int ents1_size, iBase_EntityHandle* ents2, const int ents2_size, int* err )
+void iRel_inferSetArrEntArrRelations( iRel_Instance instance,
+                                      iRel_PairHandle pair,
+                                      iBase_EntitySetHandle* ents1,
+                                      const int ents1_size,
+                                      iBase_EntityHandle* ents2,
+                                      const int ents2_size,
+                                      int* err )
 {
     iRel_inferArrArrRelations( instance, pair, (iBase_EntityHandle*)ents1, ents1_size, 1, ents2, ents2_size, 0, err );
 }
 
-void iRel_inferSetArrSetArrRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle* ents1,
-                                      const int ents1_size, int /*is_set1*/, iBase_EntitySetHandle* ents2,
-                                      const int ents2_size, int /*is_set2*/, int* err )
+void iRel_inferSetArrSetArrRelations( iRel_Instance instance,
+                                      iRel_PairHandle pair,
+                                      iBase_EntitySetHandle* ents1,
+                                      const int ents1_size,
+                                      int /*is_set1*/,
+                                      iBase_EntitySetHandle* ents2,
+                                      const int ents2_size,
+                                      int /*is_set2*/,
+                                      int* err )
 
 {
     iRel_inferArrArrRelations( instance, pair, (iBase_EntityHandle*)ents1, ents1_size, 1, (iBase_EntityHandle*)ents2,
@@ -554,24 +690,38 @@ void iRel_inferAllRelationsAndType( iRel_Instance instance, iRel_PairHandle* /*p
     ERROR( iBase_NOT_SUPPORTED, "Not currently supported." );
 }
 
-void iRel_inferEntRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle entity, int iface_no,
+void iRel_inferEntRelations( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntityHandle entity,
+                             int iface_no,
                              int* err )
 {
     iRel_inferEntArrRelations( instance, pair, &entity, 1, iface_no, err );
 }
 
-void iRel_inferSetRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle entity, int iface_no,
+void iRel_inferSetRelations( iRel_Instance instance,
+                             iRel_PairHandle pair,
+                             iBase_EntitySetHandle entity,
+                             int iface_no,
                              int* err )
 {
     iRel_inferSetArrRelations( instance, pair, &entity, 1, iface_no, err );
 }
 
-static void iRel_inferArrRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* entities,
-                                    int entities_size, bool is_set, int iface_no, int* err )
+static void iRel_inferArrRelations( iRel_Instance instance,
+                                    iRel_PairHandle pair,
+                                    iBase_EntityHandle* entities,
+                                    int entities_size,
+                                    bool is_set,
+                                    int iface_no,
+                                    int* err )
 {
     CHK_PAIR();
 
-    if( 0 > iface_no || 1 < iface_no ) { ERROR( iBase_INVALID_ARGUMENT, "Interface number must be 0 or 1" ); }
+    if( 0 > iface_no || 1 < iface_no )
+    {
+        ERROR( iBase_INVALID_ARGUMENT, "Interface number must be 0 or 1" );
+    }
     else if( ( is_set && ASSOCPAIRI->relation_type( iface_no ) == iRel_ENTITY ) ||
              ( !is_set && ASSOCPAIRI->relation_type( iface_no ) != iRel_ENTITY ) )
     {
@@ -606,14 +756,22 @@ static void iRel_inferArrRelations( iRel_Instance instance, iRel_PairHandle pair
     CHK_ERROR( result );
 }
 
-void iRel_inferEntArrRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntityHandle* entities,
-                                int entities_size, int iface_no, int* err )
+void iRel_inferEntArrRelations( iRel_Instance instance,
+                                iRel_PairHandle pair,
+                                iBase_EntityHandle* entities,
+                                int entities_size,
+                                int iface_no,
+                                int* err )
 {
     iRel_inferArrRelations( instance, pair, entities, entities_size, false, iface_no, err );
 }
 
-void iRel_inferSetArrRelations( iRel_Instance instance, iRel_PairHandle pair, iBase_EntitySetHandle* entities,
-                                int entities_size, int iface_no, int* err )
+void iRel_inferSetArrRelations( iRel_Instance instance,
+                                iRel_PairHandle pair,
+                                iBase_EntitySetHandle* entities,
+                                int entities_size,
+                                int iface_no,
+                                int* err )
 {
     iRel_inferArrRelations( instance, pair, (iBase_EntityHandle*)entities, entities_size, true, iface_no, err );
 }
