@@ -181,7 +181,9 @@ int print_mesh_info( iMesh_Instance mesh, iBase_EntityHandle ment )
   Load Mesh
   @li Load a geom and a mesh file
 */
-int load_geom_mesh_test( const char* geom_filename, const char* mesh_filename, iGeom_Instance geom,
+int load_geom_mesh_test( const char* geom_filename,
+                         const char* mesh_filename,
+                         iGeom_Instance geom,
                          iMesh_Instance mesh )
 {
     /* load a geom */
