@@ -14,8 +14,8 @@ using namespace moab;
 
 #include "TestUtil.hpp"
 
-std::string poly_example      = TestDir + "/io/poly8-10.vtk";
-std::string polyhedra_example = TestDir + "/io/polyhedra.vtk";
+std::string poly_example      = TestDir + "unittest/io/poly8-10.vtk";
+std::string polyhedra_example = TestDir + "unittest/io/polyhedra.vtk";
 
 #define DECLARE_TEST( A ) \
     bool test_##A();      \
@@ -213,8 +213,14 @@ static inline bool is_error( ErrorCode b )
 bool read_file( Interface* iface, const char* file );
 bool write_and_read( Interface* iface1, Interface* iface2 );
 
-bool test_read_write_element( const double* coords, unsigned num_coords, const int* vtk_conn, const int* moab_conn,
-                              unsigned num_conn, unsigned num_elem, unsigned vtk_type, EntityType moab_type );
+bool test_read_write_element( const double* coords,
+                              unsigned num_coords,
+                              const int* vtk_conn,
+                              const int* moab_conn,
+                              unsigned num_conn,
+                              unsigned num_elem,
+                              unsigned vtk_type,
+                              EntityType moab_type );
 
 bool test_edge2()
 {
@@ -375,7 +381,7 @@ bool test_hex20()
 bool test_hex27()
 {
     const int vtk_conn[]  = { 0,  2,  8, 6,  18, 20, 26, 24, 1,  5,  7, 3,  19, 23,
-                             25, 21, 9, 11, 17, 15, 10, 16, 14, 12, 4, 22, 13 };
+                              25, 21, 9, 11, 17, 15, 10, 16, 14, 12, 4, 22, 13 };
     const int moab_conn[] = { 0,  2,  8,  6,  18, 20, 26, 24, 1,  5,  7, 3,  9, 11,
                               17, 15, 19, 23, 25, 21, 14, 16, 12, 10, 4, 22, 13 };
 
@@ -396,9 +402,9 @@ bool test_wedge15()
                               0, 2, 2, 1, 0, 1, 2, 0, 0, 1, 0, 1, 0, 0, 1, 1, 0, 2, 1, 2, 1, 2,
                               2, 0, 1, 2, 1, 0, 2, 1, 1, 2, 2, 0, 1, 2, 2, 1, 0, 2, 1, 0, 0, 1 };
     const int exo_conn[]  = { 0, 1, 3, 4, 5, 7, 8, 12, 11, 18, 19, 21, 13, 17, 16,
-                             1, 2, 3, 5, 6, 7, 9, 10, 12, 19, 20, 21, 14, 15, 17 };
+                              1, 2, 3, 5, 6, 7, 9, 10, 12, 19, 20, 21, 14, 15, 17 };
     const int vtk_conn[]  = { 0, 3, 1, 4, 7, 5, 11, 12, 8, 16, 17, 13, 18, 21, 19,
-                             1, 3, 2, 5, 7, 6, 12, 10, 9, 17, 15, 14, 19, 21, 20 };
+                              1, 3, 2, 5, 7, 6, 12, 10, 9, 17, 15, 14, 19, 21, 20 };
     return test_read_write_element( coords, 22, vtk_conn, exo_conn, 30, 2, 26, MBPRISM );
 }
 
@@ -432,7 +438,7 @@ bool test_structured_points_2d()
                         "DIMENSIONS 4 4 1\n"
                         "ORIGIN 0 0 0\n"
                         "SPACING 1 1 1\n";
-    bool rval1 = test_structured_2d( file );
+    bool rval1        = test_structured_2d( file );
 
     // test again w/ old 1.0 ASPECT_RATIO keyword
     const char file2[] = "# vtk DataFile Version 3.0\n"
@@ -442,7 +448,7 @@ bool test_structured_points_2d()
                          "DIMENSIONS 4 4 1\n"
                          "ORIGIN 0 0 0\n"
                          "ASPECT_RATIO 1 1 1\n";
-    bool rval2 = test_structured_2d( file2 );
+    bool rval2         = test_structured_2d( file2 );
 
     return rval1 && rval2;
 }
@@ -503,7 +509,7 @@ bool test_structured_grid_2d()
                       "DATASET STRUCTURED_GRID\n"
                       "DIMENSIONS 4 4 1\n"
                       "POINTS 16 double\n";
-    int len = strlen( file );
+    int len         = strlen( file );
     for( unsigned i = 0; i < 16; ++i )
         len += sprintf( file + len, "%f %f %f\n", grid_3x3[3 * i], grid_3x3[3 * i + 1], grid_3x3[3 * i + 2] );
 
@@ -816,9 +822,15 @@ bool compare_connectivity( EntityType, const int* conn1, const int* conn2, unsig
     return true;
 }
 
-bool match_vertices_and_elements( Interface* iface, EntityType moab_type, unsigned num_vert, unsigned num_elem,
-                                  unsigned vert_per_elem, const double* coords, const int* connectivity,
-                                  EntityHandle* vert_handles, EntityHandle* elem_handles )
+bool match_vertices_and_elements( Interface* iface,
+                                  EntityType moab_type,
+                                  unsigned num_vert,
+                                  unsigned num_elem,
+                                  unsigned vert_per_elem,
+                                  const double* coords,
+                                  const int* connectivity,
+                                  EntityHandle* vert_handles,
+                                  EntityHandle* elem_handles )
 {
     ErrorCode rval;
 
@@ -911,8 +923,13 @@ bool match_vertices_and_elements( Interface* iface, EntityType moab_type, unsign
     return true;
 }
 
-bool check_elements( Interface* iface, EntityType moab_type, unsigned num_elem, unsigned vert_per_elem,
-                     const double* coords, unsigned num_vert, const int* connectivity )
+bool check_elements( Interface* iface,
+                     EntityType moab_type,
+                     unsigned num_elem,
+                     unsigned vert_per_elem,
+                     const double* coords,
+                     unsigned num_vert,
+                     const int* connectivity )
 {
     std::vector< EntityHandle > junk1( num_vert ), junk2( num_elem );
     bool rval = match_vertices_and_elements( iface, moab_type, num_vert, num_elem, vert_per_elem, coords, connectivity,
@@ -921,8 +938,14 @@ bool check_elements( Interface* iface, EntityType moab_type, unsigned num_elem,
     return true;
 }
 
-bool test_read_write_element( const double* coords, unsigned num_verts, const int* vtk_conn, const int* moab_conn,
-                              unsigned num_conn, unsigned num_elem, unsigned vtk_type, EntityType moab_type )
+bool test_read_write_element( const double* coords,
+                              unsigned num_verts,
+                              const int* vtk_conn,
+                              const int* moab_conn,
+                              unsigned num_conn,
+                              unsigned num_elem,
+                              unsigned vtk_type,
+                              EntityType moab_type )
 
 {
     // construct VTK file
@@ -930,7 +953,7 @@ bool test_read_write_element( const double* coords, unsigned num_verts, const in
                       "MOAB Version 1.00\n"
                       "ASCII\n"
                       "DATASET UNSTRUCTURED_GRID\n";
-    size_t len = strlen( file );
+    size_t len      = strlen( file );
 
     len += sprintf( file + len, "POINTS %u double\n", num_verts );
     for( unsigned i = 0; i < num_verts; ++i )
@@ -1012,7 +1035,7 @@ const double two_quad_mesh_coords[] = { -1, 0, 0, 0, 0, 0, 1, 0, 0, -1, 1, 0, 0,
 const int two_quad_mesh_conn[]      = { 0, 1, 4, 3, 1, 2, 5, 4 };
 
 const int vertex_values[]  = { 9, 3, 8, 2, 0, 6, 4, 1, 4, 1, 0, 3, 8, 6, 6, 4, 0, 2, 1, 2, 3, 4, 5, 6, 6, 5, 4,
-                              3, 2, 1, 0, 6, 1, 5, 2, 4, 3, 6, 9, 2, 5, 8, 1, 3, 5, 7, 1, 3, 5, 8, 1, 9, 7, 4 };
+                               3, 2, 1, 0, 6, 1, 5, 2, 4, 3, 6, 9, 2, 5, 8, 1, 3, 5, 7, 1, 3, 5, 8, 1, 9, 7, 4 };
 const int element_values[] = { 1001, 1002, 1004, 1003, 50, 60, 51, 61, 1, 2, 3, 4, 5, 6,
                                7,    8,    9,    0,    0,  9,  8,  7,  6, 5, 4, 3, 2, 1 };
 
@@ -1041,8 +1064,12 @@ void write_data( char* file, size_t& len, DataType type, unsigned count, const i
     }
 }
 
-bool check_tag_values( Interface* iface, DataType tag_type, int tag_length, int num_entities,
-                       const EntityHandle* entities, const int* values )
+bool check_tag_values( Interface* iface,
+                       DataType tag_type,
+                       int tag_length,
+                       int num_entities,
+                       const EntityHandle* entities,
+                       const int* values )
 {
     Tag tag;
     ErrorCode rval = iface->tag_get_handle( "data", tag_length, tag_type, tag );
