@@ -127,6 +127,8 @@ void test_sub_entity_nodes_hex_faces()
 {
     test_sub_entity_nodes( MBHEX, 2 );
 }
+void prism_issue();
+void test_wedges();
 
 int main()
 {
@@ -192,6 +194,8 @@ int main()
 
     result += RUN_TEST( test_ho_node_parent );
     result += RUN_TEST( test_ho_node_index );
+    result += RUN_TEST( prism_issue );
+    result += RUN_TEST( test_wedges );
     return result;
 }
 
@@ -397,7 +401,10 @@ void test_1d_sub_entity_indices( EntityType type, int num_edges, const int ( *ed
         int indices[3] = { 0, 0, -99 };
         // check correct results
         CN::SubEntityVertexIndices( type, 1, i, indices );
-        if( edge_indices[i][0] == indices[0] ) { CHECK_EQUAL( edge_indices[i][1], indices[1] ); }
+        if( edge_indices[i][0] == indices[0] )
+        {
+            CHECK_EQUAL( edge_indices[i][1], indices[1] );
+        }
         else
         {
             CHECK_EQUAL( edge_indices[i][0], indices[1] );
@@ -500,8 +507,7 @@ void test_sub_entity_indices_pyr()
     const int num_vtx     = 5;
     const int edges[][2]  = { { 0, 1 }, { 1, 2 }, { 2, 3 }, { 3, 0 }, { 0, 4 }, { 1, 4 }, { 2, 4 }, { 3, 4 } };
     const int faces[][5]  = {
-        { 3, 0, 1, 4, 0 }, { 3, 1, 2, 4, 0 }, { 3, 2, 3, 4, 0 }, { 3, 3, 0, 4, 0 }, { 4, 3, 2, 1, 0 }
-    };
+        { 3, 0, 1, 4, 0 }, { 3, 1, 2, 4, 0 }, { 3, 2, 3, 4, 0 }, { 3, 3, 0, 4, 0 }, { 4, 3, 2, 1, 0 } };
     test_0d_sub_entity_indices( type, num_vtx );
     test_1d_sub_entity_indices( type, sizeof( edges ) / sizeof( edges[0] ), edges );
     test_2d_sub_entity_indices( type, sizeof( faces ) / sizeof( faces[0] ), faces );
@@ -514,8 +520,7 @@ void test_sub_entity_indices_pri()
     const int num_vtx     = 6;
     const int edges[][2] = { { 0, 1 }, { 1, 2 }, { 2, 0 }, { 0, 3 }, { 1, 4 }, { 2, 5 }, { 3, 4 }, { 4, 5 }, { 5, 3 } };
     const int faces[][5] = {
-        { 4, 0, 1, 4, 3 }, { 4, 1, 2, 5, 4 }, { 4, 2, 0, 3, 5 }, { 3, 2, 1, 0, 0 }, { 3, 3, 4, 5, 0 }
-    };
+        { 4, 0, 1, 4, 3 }, { 4, 1, 2, 5, 4 }, { 4, 2, 0, 3, 5 }, { 3, 2, 1, 0, 0 }, { 3, 3, 4, 5, 0 } };
     test_0d_sub_entity_indices( type, num_vtx );
     test_1d_sub_entity_indices( type, sizeof( edges ) / sizeof( edges[0] ), edges );
     test_2d_sub_entity_indices( type, sizeof( faces ) / sizeof( faces[0] ), faces );
@@ -527,9 +532,9 @@ void test_sub_entity_indices_hex()
     const EntityType type = MBHEX;
     const int num_vtx     = 8;
     const int edges[][2]  = { { 0, 1 }, { 1, 2 }, { 2, 3 }, { 3, 0 }, { 0, 4 }, { 1, 5 },
-                             { 2, 6 }, { 3, 7 }, { 4, 5 }, { 5, 6 }, { 6, 7 }, { 7, 4 } };
+                              { 2, 6 }, { 3, 7 }, { 4, 5 }, { 5, 6 }, { 6, 7 }, { 7, 4 } };
     const int faces[][5]  = { { 4, 0, 1, 5, 4 }, { 4, 1, 2, 6, 5 }, { 4, 2, 3, 7, 6 },
-                             { 4, 3, 0, 4, 7 }, { 4, 3, 2, 1, 0 }, { 4, 4, 5, 6, 7 } };
+                              { 4, 3, 0, 4, 7 }, { 4, 3, 2, 1, 0 }, { 4, 4, 5, 6, 7 } };
     test_0d_sub_entity_indices( type, num_vtx );
     test_1d_sub_entity_indices( type, sizeof( edges ) / sizeof( edges[0] ), edges );
     test_2d_sub_entity_indices( type, sizeof( faces ) / sizeof( faces[0] ), faces );
@@ -895,9 +900,10 @@ void test_has_mid_nodes( EntityType type )
         switch( dim )
         {
             case 3:
-                if( ho_nodes[2] ) num_vtx += CN::NumSubEntities( type, 2 );
             case 2:
-                if( ho_nodes[1] ) num_vtx += CN::NumSubEntities( type, 1 );
+                // extra clauses to avoid fall-through error
+                if( 3 == dim && ho_nodes[2] ) num_vtx += CN::NumSubEntities( type, 2 );
+                if( 2 <= dim && ho_nodes[1] ) num_vtx += CN::NumSubEntities( type, 1 );
         }
         if( ho_nodes[dim] ) ++num_vtx;
 
@@ -936,9 +942,10 @@ void test_ho_node_parent()
             switch( dim )
             {
                 case 3:
-                    if( ho_nodes[2] ) num_vtx += CN::NumSubEntities( type, 2 );
                 case 2:
-                    if( ho_nodes[1] ) num_vtx += CN::NumSubEntities( type, 1 );
+                    // extra clauses to avoid fall-through error
+                    if( 3 == dim && ho_nodes[2] ) num_vtx += CN::NumSubEntities( type, 2 );
+                    if( 2 <= dim && ho_nodes[1] ) num_vtx += CN::NumSubEntities( type, 1 );
             }
             if( ho_nodes[dim] ) ++num_vtx;
 
@@ -1003,9 +1010,10 @@ void test_ho_node_index()
             switch( dim )
             {
                 case 3:
-                    if( ho_nodes[2] ) num_vtx += CN::NumSubEntities( type, 2 );
                 case 2:
-                    if( ho_nodes[1] ) num_vtx += CN::NumSubEntities( type, 1 );
+                    // extra clauses to avoid fall-through error
+                    if( 3 == dim && ho_nodes[2] ) num_vtx += CN::NumSubEntities( type, 2 );
+                    if( 2 <= dim && ho_nodes[1] ) num_vtx += CN::NumSubEntities( type, 1 );
             }
             if( ho_nodes[dim] ) ++num_vtx;
 
@@ -1048,19 +1056,26 @@ void test_sub_entity_nodes( EntityType parent, int sub_dimension )
     const int num_edge   = CN::NumSubEntities( parent, 1 );
     const int num_face   = CN::NumSubEntities( parent, 2 );
 
-    switch( CN::Dimension( parent ) )
+    auto dim = CN::Dimension( parent );
+    switch( dim )
     {
         case 3:
+        case 2:
+        case 1:
             test_sub_entity_nodes( parent, num_corner + num_face, sub_dimension );
             test_sub_entity_nodes( parent, num_corner + num_edge + num_face, sub_dimension );
             test_sub_entity_nodes( parent, num_corner + num_face + 1, sub_dimension );
             test_sub_entity_nodes( parent, num_corner + num_edge + num_face + 1, sub_dimension );
-        case 2:
-            test_sub_entity_nodes( parent, num_corner + num_edge, sub_dimension );
-            test_sub_entity_nodes( parent, num_corner + num_edge + 1, sub_dimension );
-        case 1:
-            test_sub_entity_nodes( parent, num_corner, sub_dimension );
-            test_sub_entity_nodes( parent, num_corner + 1, sub_dimension );
+            if( 2 <= dim )
+            {
+                test_sub_entity_nodes( parent, num_corner + num_edge, sub_dimension );
+                test_sub_entity_nodes( parent, num_corner + num_edge + 1, sub_dimension );
+            }
+            if( 1 <= dim )
+            {
+                test_sub_entity_nodes( parent, num_corner, sub_dimension );
+                test_sub_entity_nodes( parent, num_corner + 1, sub_dimension );
+            }
             break;
         default:
             CHECK( false );
@@ -1146,3 +1161,142 @@ void test_sub_entity_nodes( EntityType parent, int num_nodes, int sub_dimension
         CHECK_EQUAL( idx, num );
     }
 }
+
+#include "moab/Core.hpp"
+void prism_issue()
+{
+    moab::Core mb;
+
+    std::vector< moab::EntityHandle > conn;
+    double coords[3];
+    for( int i = 0; i < 15; ++i )
+    {
+        moab::EntityHandle h;
+        mb.create_vertex( coords, h );
+        conn.push_back( h );
+    }
+
+    moab::EntityHandle w;
+    mb.create_element( moab::MBPRISM, conn.data(), 15, w );
+
+    // this leads to the failure
+    {
+        std::vector< moab::EntityHandle > adj;
+        mb.get_adjacencies( &w, 1, 2, true, adj );
+    }
+    std::vector< moab::EntityHandle > edges;
+    std::vector< moab::EntityHandle > faces;
+    mb.get_entities_by_dimension( 0, 1, edges );
+    for( const auto& e : edges )
+    {
+        std::vector< moab::EntityHandle > conn;
+        std::cout << "edge " << e << " connectivity: ";
+
+        mb.get_connectivity( &e, 1, conn );
+        for( const auto& n : conn )
+            std::cout << n << " ";
+        std::cout << "\n";
+    }
+    mb.get_entities_by_dimension( 0, 2, faces );
+    for( const auto& f : faces )
+    {
+        std::vector< moab::EntityHandle > conn;
+        std::cout << "face " << f << " connectivity: ";
+
+        mb.get_connectivity( &f, 1, conn );
+        for( const auto& n : conn )
+            std::cout << n << " ";
+        std::cout << "\n";
+    }
+    std::vector< moab::EntityHandle > nodes;
+    mb.get_entities_by_dimension( 0, 0, nodes );
+    for( const auto& n : nodes )
+    {
+        std::vector< moab::EntityHandle > adj;
+        std::cout << "node " << n << " connection: ";
+        adj.clear();
+        mb.get_adjacencies( &n, 1, 1, true, adj );
+        std::cout << adj.size() << " edges,";
+        // there are either 1 or 3 adjacent edges to each vertex (1 for mid edge vertex)
+        CHECK( 1 == adj.size() || 3 == adj.size() );
+        adj.clear();
+        mb.get_adjacencies( &n, 1, 2, true, adj );
+        std::cout << adj.size() << " faces,";
+        // there are either 2 or 3 adjacent faces to each vertex ( 2 for mid edge evertex)
+        CHECK( 2 == adj.size() || 3 == adj.size() );
+        adj.clear();
+        mb.get_adjacencies( &n, 1, 3, true, adj );
+        std::cout << adj.size() << " volumes\n";
+    }
+}
+
+void test_wedges()
+{
+    moab::Core mb;
+
+    //mb.load_file("./wed15_2.h5m");
+    std::vector< moab::EntityHandle > conn;
+    double coords[3];
+    for( int i = 0; i < 22; ++i )
+    {
+        moab::EntityHandle h;
+        mb.create_vertex( coords, h );
+    }
+    moab::EntityHandle conn1[15] = { 10, 20, 14, 1, 8, 5, 21, 19, 15, 16, 22, 18, 9, 7, 6 };
+    moab::EntityHandle conn2[15] = { 10, 14, 12, 1, 5, 3, 15, 13, 11, 16, 18, 17, 6, 4, 2 };
+
+    moab::EntityHandle w;
+    mb.create_element( moab::MBPRISM, conn1, 15, w );
+    mb.create_element( moab::MBPRISM, conn2, 15, w );
+
+    std::vector< moab::EntityHandle > wedges;
+    mb.get_entities_by_dimension( 0, 3, wedges );
+
+    // > If I comment this block there is no problem
+    for( const auto& w : wedges )
+    {
+        std::vector< moab::EntityHandle > adj;
+        mb.get_adjacencies( &w, 1, 2, true, adj );
+        CHECK( 5 == adj.size() );
+    }
+    // <
+
+    for( const auto& w : wedges )
+    {
+        std::vector< moab::EntityHandle > conn;
+        mb.get_connectivity( &w, 1, conn );
+        CHECK( 15 == conn.size() );
+        for( const auto& n : conn )
+        {
+            std::vector< moab::EntityHandle > edges;
+            mb.get_adjacencies( &n, 1, 1, true, edges );
+            if( edges.size() == 0 )
+            {
+                std::cout << " node " << n << " not connected to edges \n";
+                std::vector< moab::EntityHandle > faces;
+                mb.get_adjacencies( &n, 1, 2, false, faces );
+                for( const auto& f : faces )
+                {
+                    std::vector< moab::EntityHandle > connf;
+                    mb.get_connectivity( &f, 1, connf );
+                    std::cout << "face:" << mb.id_from_handle( f );
+                    for( const auto& n1 : connf )
+                        std::cout << " " << n1;
+                    std::cout << "\n";
+                }
+                std::vector< moab::EntityHandle > prisms;
+                mb.get_adjacencies( &n, 1, 3, false, prisms );
+                for( const auto& p : prisms )
+                {
+                    std::vector< moab::EntityHandle > connf;
+                    mb.get_connectivity( &p, 1, connf );
+                    std::cout << "prism:" << mb.id_from_handle( p );
+                    for( const auto& n1 : connf )
+                        std::cout << " " << n1;
+                    std::cout << "\n";
+                }
+                CHECK( edges.size() != 0 );
+            }
+        }
+    }
+}
