@@ -62,7 +62,7 @@ ErrorCode write_geometry( const char* output_file_name )
     // Define a 2x2x2 cube centered at orgin
     // with concavity in +Z face.
     const double coords[]    = { 1, -1, -1, 1, 1,  -1, -1, 1,  -1, -1, -1, -1, 1, -1,
-                              1, 1,  1,  1, -1, 1,  1,  -1, -1, 1,  0,  0,  0 };
+                                 1, 1,  1,  1, -1, 1,  1,  -1, -1, 1,  0,  0,  0 };
     const int connectivity[] = {
         0, 3, 1, 3, 2, 1,  // -Z
         0, 1, 4, 5, 4, 1,  // +X
@@ -141,9 +141,9 @@ ErrorCode overlap_write_geometry( const char* output_file_name )
     // Define two 1x2x2 cubes that overlap from 0 <= x <= 0.01
     // cube 0 centered at (0.5,0,0)
     const double coords[]    = { 1, -1, -1, 1, 1, -1, 0, 1, -1, 0, -1, -1, 1, -1, 1, 1, 1, 1, 0, 1, 1, 0, -1, 1,
-                              // cube 1 centered near (-0.5,0,0)
-                              0.01, -1, -1, 0.01, 1, -1, -1, 1, -1, -1, -1, -1, 0.01, -1, 1, 0.01, 1, 1, -1, 1, 1, -1,
-                              -1, 1 };
+                                 // cube 1 centered near (-0.5,0,0)
+                                 0.01, -1, -1, 0.01, 1, -1, -1, 1, -1, -1, -1, -1, 0.01, -1, 1, 0.01, 1, 1, -1, 1, 1, -1,
+                                 -1, 1 };
     const int connectivity[] = { 0, 3, 1, 3, 2, 1,    // -Z
                                  0, 1, 4, 5, 4, 1,    // +X
                                  1, 2, 6, 6, 5, 1,    // +Y
@@ -221,11 +221,14 @@ ErrorCode overlap_write_geometry( const char* output_file_name )
     return MB_SUCCESS;
 }
 
-#define RUN_TEST( A )                              \
-    do                                             \
-    {                                              \
-        std::cout << #A << "... " << std::endl;    \
-        if( MB_SUCCESS != A( gqt ) ) { ++errors; } \
+#define RUN_TEST( A )                           \
+    do                                          \
+    {                                           \
+        std::cout << #A << "... " << std::endl; \
+        if( MB_SUCCESS != A( gqt ) )            \
+        {                                       \
+            ++errors;                           \
+        }                                       \
     } while( false )
 
 int main( int argc, char* argv[] )
@@ -611,8 +614,7 @@ ErrorCode test_ray_fire( GeomQueryTool* gqt )
                                       // piercing node
                                       { 1, { 0.0, 0.0, -1. }, { 0.0, 0.0, 1.0 }, 6, 1.0 },
                                       // glancing edge then interior
-                                      { 2, { 1.0, 0.0, 0.5 }, { -1.0 / ROOT2, 1.0 / ROOT2, 0.0 }, 3, ROOT2 }
-    };
+                                      { 2, { 1.0, 0.0, 0.5 }, { -1.0 / ROOT2, 1.0 / ROOT2, 0.0 }, 3, ROOT2 } };
 
     ErrorCode rval;
     Interface* moab = gqt->moab_instance();
@@ -755,8 +757,7 @@ ErrorCode overlap_test_ray_fire( GeomQueryTool* gqt )
                                       { 8, { -0.5, 0.0, 0.0 }, { -1.0, 0.0, 0.0 }, 10, 0.5 },
                                       // numerical location on surface 9 of region1
                                       { 10, { -1.0, 0.0, 0.0 }, { 1.0, 0.0, 0.0 }, 8, 1.01 },
-                                      { 8, { -1.0, 0.0, 0.0 }, { -1.0, 0.0, 0.0 }, 10, 0.0 }
-    };
+                                      { 8, { -1.0, 0.0, 0.0 }, { -1.0, 0.0, 0.0 }, 10, 0.0 } };
 
     ErrorCode rval;
     Interface* moab = gqt->moab_instance();
