@@ -43,6 +43,8 @@
 
 #ifdef MOAB_HAVE_TEMPESTREMAP
 #include "moab/Remapping/TempestRemapper.hpp"
+
+constexpr bool offlineGenerator = true;
 #endif
 
 #include <cstdio>
@@ -88,6 +90,7 @@ static void print_usage( const char* name, std::ostream& stream )
 #ifdef MOAB_HAVE_TEMPESTREMAP
            << "\t-B             - Use TempestRemap exodus file reader and convert to MOAB format" << std::endl
            << "\t-b             - Convert MOAB mesh to TempestRemap exodus file writer" << std::endl
+           << "\t-S             - Scale climate mesh to unit sphere" << std::endl
            << "\t-i             - Name of the global DoF tag to use with mbtempest" << std::endl
            << "\t-r             - Order of field DoF (discretization) data; FV=1,SE=[1,N]" << std::endl
 #endif
@@ -177,6 +180,7 @@ int main( int argc, char* argv[] )
 
     bool append_rank        = false;
     bool percent_rank_subst = false;
+    bool file_written       = false;
     int i, dim;
     std::list< std::string >::iterator j;
     bool dims[4]       = { false, false, false, false };
@@ -191,6 +195,7 @@ int main( int argc, char* argv[] )
 #ifdef MOAB_HAVE_TEMPESTREMAP
     std::string globalid_tag_name;
     int spectral_order = 1;
+    bool unitscaling   = false;
 #endif
 
     const char* const mesh_tag_names[] = { DIRICHLET_SET_TAG_NAME, NEUMANN_SET_TAG_NAME, MATERIAL_SET_TAG_NAME,
@@ -243,6 +248,7 @@ int main( int argc, char* argv[] )
                     parallel = true;
                     if( argv[i][2] == '1' || argv[i][2] == '2' ) resolve_shared = true;
                     if( argv[i][2] == '2' ) exchange_ghosts = true;
+                    break;
 #endif
 #ifdef MOAB_HAVE_TEMPESTREMAP
                 case 'B':
@@ -251,6 +257,9 @@ int main( int argc, char* argv[] )
                 case 'b':
                     tempestout = true;
                     break;
+                case 'S':
+                    unitscaling = true;
+                    break;
 #endif
                 case '1':
                 case '2':
@@ -416,12 +425,15 @@ int main( int argc, char* argv[] )
 #endif
         return USAGE_ERROR;
     }
-
+    TempestRemapper* remapper = NULL;
+    if( tempestin or tempestout )
+    {
 #ifdef MOAB_HAVE_MPI
-    TempestRemapper* remapper = new moab::TempestRemapper( gMB, pcomm );
+        remapper = new moab::TempestRemapper( gMB, pcomm, offlineGenerator );
 #else
-    TempestRemapper* remapper = new moab::TempestRemapper( gMB );
+        remapper      = new moab::TempestRemapper( gMB, offlineGenerator );
 #endif
+    }
 
     bool use_overlap_context = false;
     Tag srcParentTag, tgtParentTag;
@@ -434,198 +446,208 @@ int main( int argc, char* argv[] )
         reset_times();
 
 #ifdef MOAB_HAVE_TEMPESTREMAP
-
-        remapper->meshValidate = false;
-        // remapper->constructEdgeMap = true;
-        remapper->initialize();
-
-        if( tempestin )
+        if( remapper )
         {
-            // convert
-            result = remapper->LoadMesh( moab::Remapper::SourceMesh, inFileName, moab::TempestRemapper::DEFAULT );MB_CHK_ERR( result );
+            remapper->meshValidate = false;
+            // remapper->constructEdgeMap = true;
+            remapper->initialize();
 
-            Mesh* tempestMesh = remapper->GetMesh( moab::Remapper::SourceMesh );
-            tempestMesh->RemoveZeroEdges();
-            tempestMesh->RemoveCoincidentNodes();
-
-            // Load the meshes and validate
-            result = remapper->ConvertTempestMesh( moab::Remapper::SourceMesh );
-
-            // Check if we are converting a RLL grid
-            NcFile ncInput( inFileName.c_str(), NcFile::ReadOnly );
-            bool isRectilinearGrid = false;
-
-            NcError error_temp( NcError::silent_nonfatal );
-            // get the attribute
-            NcAtt* attRectilinear = ncInput.get_att( "rectilinear" );
-
-            // If rectilinear attribute present, mark it
-            std::vector< int > vecDimSizes( 3, 0 );
-            Tag rectilinearTag;
-            // Tag data contains: guessed mesh type,     mesh size1,     mesh size 2
-            //          Example:  CS(0)/ICO(1)/ICOD(2),  num_elements,   num_nodes
-            //                 :       RLL(3),           num_lat,        num_lon
-            result = gMB->tag_get_handle( "ClimateMetadata", 3, MB_TYPE_INTEGER, rectilinearTag,
-                                          MB_TAG_SPARSE | MB_TAG_CREAT, vecDimSizes.data() );MB_CHK_SET_ERR( result, "can't create rectilinear sizes tag" );
-
-            if( attRectilinear != nullptr )
+            if( tempestin )
             {
-                isRectilinearGrid = true;
+                moab::EntityHandle& srcmesh = remapper->GetMeshSet( moab::Remapper::SourceMesh );
 
-                // Obtain rectilinear attributes (dimension sizes)
-                NcAtt* attRectilinearDim0Size = ncInput.get_att( "rectilinear_dim0_size" );
-                NcAtt* attRectilinearDim1Size = ncInput.get_att( "rectilinear_dim1_size" );
+                // convert
+                result = remapper->LoadMesh( moab::Remapper::SourceMesh, inFileName, moab::TempestRemapper::DEFAULT );MB_CHK_ERR( result );
 
-                if( attRectilinearDim0Size == nullptr )
-                {
-                    _EXCEPTIONT( "Missing attribute \"rectilinear_dim0_size\"" );
-                }
-                if( attRectilinearDim1Size == nullptr )
-                {
-                    _EXCEPTIONT( "Missing attribute \"rectilinear_dim1_size\"" );
-                }
-
-                int nDim0Size = attRectilinearDim0Size->as_int( 0 );
-                int nDim1Size = attRectilinearDim1Size->as_int( 0 );
-
-                // Obtain rectilinear attributes (dimension names)
-                NcAtt* attRectilinearDim0Name = ncInput.get_att( "rectilinear_dim0_name" );
-                NcAtt* attRectilinearDim1Name = ncInput.get_att( "rectilinear_dim1_name" );
-
-                if( attRectilinearDim0Name == nullptr )
-                {
-                    _EXCEPTIONT( "Missing attribute \"rectilinear_dim0_name\"" );
-                }
-                if( attRectilinearDim1Name == nullptr )
-                {
-                    _EXCEPTIONT( "Missing attribute \"rectilinear_dim1_name\"" );
-                }
-
-                std::string strDim0Name = attRectilinearDim0Name->as_string( 0 );
-                std::string strDim1Name = attRectilinearDim1Name->as_string( 0 );
-
-                std::map< std::string, int > vecDimNameSizes;
-                // Push rectilinear attributes into array
-                vecDimNameSizes[strDim0Name] = nDim0Size;
-                vecDimNameSizes[strDim1Name] = nDim1Size;
-                vecDimSizes[0]               = static_cast< int >( moab::TempestRemapper::RLL );
-                vecDimSizes[1]               = vecDimNameSizes["lat"];
-                vecDimSizes[2]               = vecDimNameSizes["lon"];
-
-                printf( "Rectilinear RLL mesh size: (lat) %d X (lon) %d\n", vecDimSizes[1], vecDimSizes[2] );
-
-                moab::EntityHandle mSet = 0;
-                // mSet   = remapper->GetMeshSet( moab::Remapper::SourceMesh );
-                result = gMB->tag_set_data( rectilinearTag, &mSet, 1, vecDimSizes.data() );MB_CHK_ERR( result );
-            }
-            else
-            {
-                const Range& elems = remapper->GetMeshEntities( moab::Remapper::SourceMesh );
-                bool isQuads       = elems.all_of_type( moab::MBQUAD );
-                bool isTris        = elems.all_of_type( moab::MBTRI );
-                // vecDimSizes[0] = static_cast< int >( remapper->GetMeshType( moab::Remapper::SourceMesh );
-                vecDimSizes[0] = ( isQuads ? static_cast< int >( moab::TempestRemapper::CS )
-                                           : ( isTris ? static_cast< int >( moab::TempestRemapper::ICO )
-                                                      : static_cast< int >( moab::TempestRemapper::ICOD ) ) );
-                vecDimSizes[1] = elems.size();
-                vecDimSizes[2] = remapper->GetMeshVertices( moab::Remapper::SourceMesh ).size();
-
-                switch( vecDimSizes[0] )
-                {
-                    case 0:
-                        printf( "Cubed-Sphere mesh: %d (elems), %d (nodes)\n", vecDimSizes[1], vecDimSizes[2] );
-                        break;
-                    case 2:
-                        printf( "Icosahedral (triangular) mesh: %d (elems), %d (nodes)\n", vecDimSizes[1],
-                                vecDimSizes[2] );
-                        break;
-                    case 3:
-                    default:
-                        printf( "Polygonal mesh: %d (elems), %d (nodes)\n", vecDimSizes[1], vecDimSizes[2] );
-                        break;
-                }
-
-                moab::EntityHandle mSet = 0;
-                // mSet   = remapper->GetMeshSet( moab::Remapper::SourceMesh );
-                result = gMB->tag_set_data( rectilinearTag, &mSet, 1, vecDimSizes.data() );MB_CHK_ERR( result );
-            }
-
-            ncInput.close();
-
-            const size_t nOverlapFaces = tempestMesh->faces.size();
-            if( tempestMesh->vecSourceFaceIx.size() == nOverlapFaces &&
-                tempestMesh->vecSourceFaceIx.size() == nOverlapFaces )
-            {
-                int defaultInt      = -1;
-                use_overlap_context = true;
-                // Check if our MOAB mesh has RED and BLUE tags; this would indicate we are
-                // converting an overlap grid
-                result = gMB->tag_get_handle( "TargetParent", 1, MB_TYPE_INTEGER, tgtParentTag,
-                                              MB_TAG_DENSE | MB_TAG_CREAT, &defaultInt );MB_CHK_SET_ERR( result, "can't create target parent tag" );
-
-                result = gMB->tag_get_handle( "SourceParent", 1, MB_TYPE_INTEGER, srcParentTag,
-                                              MB_TAG_DENSE | MB_TAG_CREAT, &defaultInt );MB_CHK_SET_ERR( result, "can't create source parent tag" );
-
-                const Range& faces = remapper->GetMeshEntities( moab::Remapper::SourceMesh );
-
-                std::vector< int > gids( faces.size() ), srcpar( faces.size() ), tgtpar( faces.size() );
-                result = gMB->tag_get_data( id_tag, faces, &gids[0] );MB_CHK_ERR( result );
-
-                for( unsigned ii = 0; ii < faces.size(); ++ii )
-                {
-                    srcpar[ii] = tempestMesh->vecSourceFaceIx[gids[ii] - 1];
-                    tgtpar[ii] = tempestMesh->vecTargetFaceIx[gids[ii] - 1];
-                }
-
-                result = gMB->tag_set_data( srcParentTag, faces, &srcpar[0] );MB_CHK_ERR( result );
-                result = gMB->tag_set_data( tgtParentTag, faces, &tgtpar[0] );MB_CHK_ERR( result );
-
-                srcpar.clear();
-                tgtpar.clear();
-                gids.clear();
-            }
-        }
-        else if( tempestout )
-        {
-            moab::EntityHandle& srcmesh = remapper->GetMeshSet( moab::Remapper::SourceMesh );
-            moab::EntityHandle& ovmesh  = remapper->GetMeshSet( moab::Remapper::OverlapMesh );
-
-            // load the mesh in MOAB format
-            std::vector< int > metadata;
-            result = remapper->LoadNativeMesh( *j, srcmesh, metadata );MB_CHK_ERR( result );
-
-            // Check if our MOAB mesh has RED and BLUE tags; this would indicate we are converting
-            // an overlap grid
-            ErrorCode rval1 = gMB->tag_get_handle( "SourceParent", srcParentTag );
-            ErrorCode rval2 = gMB->tag_get_handle( "TargetParent", tgtParentTag );
-            if( rval1 == MB_SUCCESS && rval2 == MB_SUCCESS )
-            {
-                use_overlap_context = true;
-                ovmesh              = srcmesh;
-
-                Tag countTag;
-                result = gMB->tag_get_handle( "Counting", countTag );
-                // std::vector<int> count_ids()
+                Mesh* tempestMesh = remapper->GetMesh( moab::Remapper::SourceMesh );
+                tempestMesh->RemoveZeroEdges();
+                tempestMesh->RemoveCoincidentNodes();
 
                 // Load the meshes and validate
-                Tag order;
-                ReorderTool reorder_tool( &core );
-                result = reorder_tool.handle_order_from_int_tag( srcParentTag, -1, order );MB_CHK_ERR( result );
-                result = reorder_tool.reorder_entities( order );MB_CHK_ERR( result );
-                result = gMB->tag_delete( order );MB_CHK_ERR( result );
-                result = remapper->ConvertMeshToTempest( moab::Remapper::OverlapMesh );MB_CHK_ERR( result );
-            }
-            else
-            {
-                if( metadata[0] == static_cast< int >( moab::TempestRemapper::RLL ) )
+                result = remapper->ConvertTempestMesh( moab::Remapper::SourceMesh );
+
+                if( unitscaling )
                 {
-                    assert( metadata.size() );
-                    std::cout << "Converting a RLL mesh with rectilinear dimension: " << metadata[0] << " X "
-                              << metadata[1] << std::endl;
+                    result = moab::IntxUtils::ScaleToRadius( gMB, srcmesh, 1.0 );MB_CHK_ERR( result );
                 }
 
-                // Convert the mesh and validate
-                result = remapper->ConvertMeshToTempest( moab::Remapper::SourceMesh );MB_CHK_ERR( result );
+                // Check if we are converting a RLL grid
+                NcFile ncInput( inFileName.c_str(), NcFile::ReadOnly );
+
+                NcError error_temp( NcError::silent_nonfatal );
+                // get the attribute
+                NcAtt* attRectilinear = ncInput.get_att( "rectilinear" );
+
+                // If rectilinear attribute present, mark it
+                std::vector< int > vecDimSizes( 3, 0 );
+                Tag rectilinearTag;
+                // Tag data contains: guessed mesh type,     mesh size1,     mesh size 2
+                //          Example:  CS(0)/ICO(1)/ICOD(2),  num_elements,   num_nodes
+                //                 :       RLL(3),           num_lat,        num_lon
+                result = gMB->tag_get_handle( "ClimateMetadata", 3, MB_TYPE_INTEGER, rectilinearTag,
+                                              MB_TAG_SPARSE | MB_TAG_CREAT, vecDimSizes.data() );MB_CHK_SET_ERR( result, "can't create rectilinear sizes tag" );
+
+                if( attRectilinear != nullptr )
+                {
+                    // Obtain rectilinear attributes (dimension sizes)
+                    NcAtt* attRectilinearDim0Size = ncInput.get_att( "rectilinear_dim0_size" );
+                    NcAtt* attRectilinearDim1Size = ncInput.get_att( "rectilinear_dim1_size" );
+
+                    if( attRectilinearDim0Size == nullptr )
+                    {
+                        _EXCEPTIONT( "Missing attribute \"rectilinear_dim0_size\"" );
+                    }
+                    if( attRectilinearDim1Size == nullptr )
+                    {
+                        _EXCEPTIONT( "Missing attribute \"rectilinear_dim1_size\"" );
+                    }
+
+                    int nDim0Size = attRectilinearDim0Size->as_int( 0 );
+                    int nDim1Size = attRectilinearDim1Size->as_int( 0 );
+
+                    // Obtain rectilinear attributes (dimension names)
+                    NcAtt* attRectilinearDim0Name = ncInput.get_att( "rectilinear_dim0_name" );
+                    NcAtt* attRectilinearDim1Name = ncInput.get_att( "rectilinear_dim1_name" );
+
+                    if( attRectilinearDim0Name == nullptr )
+                    {
+                        _EXCEPTIONT( "Missing attribute \"rectilinear_dim0_name\"" );
+                    }
+                    if( attRectilinearDim1Name == nullptr )
+                    {
+                        _EXCEPTIONT( "Missing attribute \"rectilinear_dim1_name\"" );
+                    }
+
+                    std::string strDim0Name = attRectilinearDim0Name->as_string( 0 );
+                    std::string strDim1Name = attRectilinearDim1Name->as_string( 0 );
+
+                    std::map< std::string, int > vecDimNameSizes;
+                    // Push rectilinear attributes into array
+                    vecDimNameSizes[strDim0Name] = nDim0Size;
+                    vecDimNameSizes[strDim1Name] = nDim1Size;
+                    vecDimSizes[0]               = static_cast< int >( moab::TempestRemapper::RLL );
+                    vecDimSizes[1]               = vecDimNameSizes["lat"];
+                    vecDimSizes[2]               = vecDimNameSizes["lon"];
+
+                    printf( "Rectilinear RLL mesh size: (lat) %d X (lon) %d\n", vecDimSizes[1], vecDimSizes[2] );
+
+                    moab::EntityHandle mSet = 0;
+                    // mSet   = remapper->GetMeshSet( moab::Remapper::SourceMesh );
+                    result = gMB->tag_set_data( rectilinearTag, &mSet, 1, vecDimSizes.data() );MB_CHK_ERR( result );
+                }
+                else
+                {
+                    const Range& elems = remapper->GetMeshEntities( moab::Remapper::SourceMesh );
+                    bool isQuads       = elems.all_of_type( moab::MBQUAD );
+                    bool isTris        = elems.all_of_type( moab::MBTRI );
+                    // vecDimSizes[0] = static_cast< int >( remapper->GetMeshType( moab::Remapper::SourceMesh );
+                    vecDimSizes[0] = ( isQuads ? static_cast< int >( moab::TempestRemapper::CS )
+                                               : ( isTris ? static_cast< int >( moab::TempestRemapper::ICO )
+                                                          : static_cast< int >( moab::TempestRemapper::ICOD ) ) );
+                    vecDimSizes[1] = elems.size();
+                    vecDimSizes[2] = remapper->GetMeshVertices( moab::Remapper::SourceMesh ).size();
+
+                    switch( vecDimSizes[0] )
+                    {
+                        case 0:
+                            printf( "Cubed-Sphere mesh: %d (elems), %d (nodes)\n", vecDimSizes[1], vecDimSizes[2] );
+                            break;
+                        case 2:
+                            printf( "Icosahedral (triangular) mesh: %d (elems), %d (nodes)\n", vecDimSizes[1],
+                                    vecDimSizes[2] );
+                            break;
+                        case 3:
+                        default:
+                            printf( "Polygonal mesh: %d (elems), %d (nodes)\n", vecDimSizes[1], vecDimSizes[2] );
+                            break;
+                    }
+
+                    moab::EntityHandle mSet = 0;
+                    // mSet   = remapper->GetMeshSet( moab::Remapper::SourceMesh );
+                    result = gMB->tag_set_data( rectilinearTag, &mSet, 1, vecDimSizes.data() );MB_CHK_ERR( result );
+                }
+
+                ncInput.close();
+
+                const size_t nOverlapFaces = tempestMesh->faces.size();
+                if( tempestMesh->vecSourceFaceIx.size() == nOverlapFaces &&
+                    tempestMesh->vecSourceFaceIx.size() == nOverlapFaces )
+                {
+                    int defaultInt      = -1;
+                    use_overlap_context = true;
+                    // Check if our MOAB mesh has RED and BLUE tags; this would indicate we are
+                    // converting an overlap grid
+                    result = gMB->tag_get_handle( "TargetParent", 1, MB_TYPE_INTEGER, tgtParentTag,
+                                                  MB_TAG_DENSE | MB_TAG_CREAT, &defaultInt );MB_CHK_SET_ERR( result, "can't create target parent tag" );
+
+                    result = gMB->tag_get_handle( "SourceParent", 1, MB_TYPE_INTEGER, srcParentTag,
+                                                  MB_TAG_DENSE | MB_TAG_CREAT, &defaultInt );MB_CHK_SET_ERR( result, "can't create source parent tag" );
+
+                    const Range& faces = remapper->GetMeshEntities( moab::Remapper::SourceMesh );
+
+                    std::vector< int > gids( faces.size() ), srcpar( faces.size() ), tgtpar( faces.size() );
+                    result = gMB->tag_get_data( id_tag, faces, &gids[0] );MB_CHK_ERR( result );
+
+                    for( unsigned ii = 0; ii < faces.size(); ++ii )
+                    {
+                        srcpar[ii] = tempestMesh->vecSourceFaceIx[gids[ii] - 1];
+                        tgtpar[ii] = tempestMesh->vecTargetFaceIx[gids[ii] - 1];
+                    }
+
+                    result = gMB->tag_set_data( srcParentTag, faces, &srcpar[0] );MB_CHK_ERR( result );
+                    result = gMB->tag_set_data( tgtParentTag, faces, &tgtpar[0] );MB_CHK_ERR( result );
+
+                    srcpar.clear();
+                    tgtpar.clear();
+                    gids.clear();
+                }
+            }
+            else if( tempestout )
+            {
+                moab::EntityHandle& srcmesh = remapper->GetMeshSet( moab::Remapper::SourceMesh );
+                moab::EntityHandle& ovmesh  = remapper->GetMeshSet( moab::Remapper::OverlapMesh );
+
+                // load the mesh in MOAB format
+                std::vector< int > metadata( 2 );
+                result = remapper->LoadNativeMesh( *j, srcmesh, metadata );MB_CHK_ERR( result );
+
+                if( unitscaling )
+                {
+                    result = moab::IntxUtils::ScaleToRadius( gMB, srcmesh, 1.0 );MB_CHK_ERR( result );
+                }
+
+                // Check if our MOAB mesh has RED and BLUE tags; this would indicate we are converting
+                // an overlap grid
+                ErrorCode rval1 = gMB->tag_get_handle( "SourceParent", srcParentTag );
+                ErrorCode rval2 = gMB->tag_get_handle( "TargetParent", tgtParentTag );
+                if( rval1 == MB_SUCCESS && rval2 == MB_SUCCESS )
+                {
+                    use_overlap_context = true;
+                    ovmesh              = srcmesh;
+
+                    Tag countTag;
+                    result = gMB->tag_get_handle( "Counting", countTag );MB_CHK_ERR( result );
+
+                    // Load the meshes and validate
+                    Tag order;
+                    ReorderTool reorder_tool( &core );
+                    result = reorder_tool.handle_order_from_int_tag( srcParentTag, -1, order );MB_CHK_ERR( result );
+                    result = reorder_tool.reorder_entities( order );MB_CHK_ERR( result );
+                    result = gMB->tag_delete( order );MB_CHK_ERR( result );
+                    result = remapper->ConvertMeshToTempest( moab::Remapper::OverlapMesh );MB_CHK_ERR( result );
+                }
+                else
+                {
+                    if( metadata[0] == static_cast< int >( moab::TempestRemapper::RLL ) )
+                    {
+                        assert( metadata.size() );
+                        std::cout << "Converting a RLL mesh with rectilinear dimension: " << metadata[0] << " X "
+                                  << metadata[1] << std::endl;
+                    }
+
+                    // Convert the mesh and validate
+                    result = remapper->ConvertMeshToTempest( moab::Remapper::SourceMesh );MB_CHK_ERR( result );
+                }
             }
         }
         else
@@ -783,7 +805,10 @@ int main( int argc, char* argv[] )
                 gMB->get_adjacencies( dim3, 1, true, adj, Interface::UNION );
                 gMB->get_adjacencies( dim2, 1, true, adj, Interface::UNION );
             }
-            if( generate[2] ) { gMB->get_adjacencies( dim3, 2, true, adj, Interface::UNION ); }
+            if( generate[2] )
+            {
+                gMB->get_adjacencies( dim3, 2, true, adj, Interface::UNION );
+            }
             if( sets[i] ) gMB->add_entities( sets[i], adj );
         }
     }
@@ -849,63 +874,68 @@ int main( int argc, char* argv[] )
     // Write the output file
     reset_times();
 #ifdef MOAB_HAVE_TEMPESTREMAP
-    Range faces;
-    Mesh* tempestMesh =
-        remapper->GetMesh( ( use_overlap_context ? moab::Remapper::OverlapMesh : moab::Remapper::SourceMesh ) );
-    moab::EntityHandle& srcmesh =
-        remapper->GetMeshSet( ( use_overlap_context ? moab::Remapper::OverlapMesh : moab::Remapper::SourceMesh ) );
-    result = gMB->get_entities_by_dimension( srcmesh, 2, faces );MB_CHK_ERR( result );
-    int ntot_elements = 0, nelements = faces.size();
+    if( remapper )
+    {
+        Range faces;
+        Mesh* tempestMesh =
+            remapper->GetMesh( ( use_overlap_context ? moab::Remapper::OverlapMesh : moab::Remapper::SourceMesh ) );
+        moab::EntityHandle& srcmesh =
+            remapper->GetMeshSet( ( use_overlap_context ? moab::Remapper::OverlapMesh : moab::Remapper::SourceMesh ) );
+        result = gMB->get_entities_by_dimension( srcmesh, 2, faces );MB_CHK_ERR( result );
+        int ntot_elements = 0, nelements = faces.size();
 #ifdef MOAB_HAVE_MPI
-    int ierr = MPI_Allreduce( &nelements, &ntot_elements, 1, MPI_INT, MPI_SUM, pcomm->comm() );
-    if( ierr != 0 ) MB_CHK_SET_ERR( MB_FAILURE, "MPI_Allreduce failed to get total source elements" );
+        int ierr = MPI_Allreduce( &nelements, &ntot_elements, 1, MPI_INT, MPI_SUM, pcomm->comm() );
+        if( ierr != 0 ) MB_CHK_SET_ERR( MB_FAILURE, "MPI_Allreduce failed to get total source elements" );
 #else
-    ntot_elements             = nelements;
+        ntot_elements = nelements;
 #endif
 
-    Tag gidTag = gMB->globalId_tag();
-    std::vector< int > gids( faces.size() );
-    result = gMB->tag_get_data( gidTag, faces, &gids[0] );MB_CHK_ERR( result );
+        Tag gidTag = gMB->globalId_tag();
+        std::vector< int > gids( faces.size() );
+        result = gMB->tag_get_data( gidTag, faces, &gids[0] );MB_CHK_ERR( result );
 
-    if( faces.size() > 1 && gids[0] == gids[1] && !use_overlap_context )
-    {
-#ifdef MOAB_HAVE_MPI
-        result = pcomm->assign_global_ids( srcmesh, 2, 1, false );MB_CHK_ERR( result );
-#else
-        result = remapper->assign_vertex_element_IDs( gidTag, srcmesh, 2, 1 );MB_CHK_ERR( result );
-        result = remapper->assign_vertex_element_IDs( gidTag, srcmesh, 0, 1 );MB_CHK_ERR( result );
-#endif
-    }
-
-    // VSM: If user requested explicitly for some metadata, we need to generate the DoF ID tag
-    // and set the appropriate numbering based on specified discretization order
-    // Useful only for SE meshes with GLL DoFs
-    if( spectral_order > 1 && globalid_tag_name.size() > 1 )
-    {
-        result = remapper->GenerateMeshMetadata( *tempestMesh, ntot_elements, faces, NULL, globalid_tag_name,
-                                                 spectral_order );MB_CHK_ERR( result );
-    }
-
-    if( tempestout )
-    {
-        // Check if our MOAB mesh has RED and BLUE tags; this would indicate we are converting an
-        // overlap grid
-        if( use_overlap_context && false )
+        if( faces.size() > 1 && gids[0] == gids[1] && !use_overlap_context )
         {
-            const int nOverlapFaces = faces.size();
-            // Overlap mesh: resize the source and target connection arrays
-            tempestMesh->vecSourceFaceIx.resize( nOverlapFaces );  // 0-based indices corresponding to source mesh
-            tempestMesh->vecTargetFaceIx.resize( nOverlapFaces );  // 0-based indices corresponding to target mesh
-            result = gMB->tag_get_data( srcParentTag, faces, &tempestMesh->vecSourceFaceIx[0] );MB_CHK_ERR( result );
-            result = gMB->tag_get_data( tgtParentTag, faces, &tempestMesh->vecTargetFaceIx[0] );MB_CHK_ERR( result );
+#ifdef MOAB_HAVE_MPI
+            result = pcomm->assign_global_ids( srcmesh, 2, 1, false );MB_CHK_ERR( result );
+#else
+            result = remapper->assign_vertex_element_IDs( gidTag, srcmesh, 2, 1 );MB_CHK_ERR( result );
+            result = remapper->assign_vertex_element_IDs( gidTag, srcmesh, 0, 1 );MB_CHK_ERR( result );
+#endif
         }
-        // Write out the mesh using TempestRemap
-        tempestMesh->Write( out, NcFile::Netcdf4 );
+
+        // VSM: If user requested explicitly for some metadata, we need to generate the DoF ID tag
+        // and set the appropriate numbering based on specified discretization order
+        // Useful only for SE meshes with GLL DoFs
+        if( spectral_order > 1 && globalid_tag_name.size() > 1 )
+        {
+            result = remapper->GenerateMeshMetadata( *tempestMesh, ntot_elements, faces, NULL, globalid_tag_name,
+                                                     spectral_order );MB_CHK_ERR( result );
+        }
+
+        if( tempestout )
+        {
+            // Check if our MOAB mesh has RED and BLUE tags; this would indicate we are converting an
+            // overlap grid
+            if( use_overlap_context && false )
+            {
+                const int nOverlapFaces = faces.size();
+                // Overlap mesh: resize the source and target connection arrays
+                tempestMesh->vecSourceFaceIx.resize( nOverlapFaces );  // 0-based indices corresponding to source mesh
+                tempestMesh->vecTargetFaceIx.resize( nOverlapFaces );  // 0-based indices corresponding to target mesh
+                result = gMB->tag_get_data( srcParentTag, faces, &tempestMesh->vecSourceFaceIx[0] );MB_CHK_ERR( result );
+                result = gMB->tag_get_data( tgtParentTag, faces, &tempestMesh->vecTargetFaceIx[0] );MB_CHK_ERR( result );
+            }
+            // Write out the mesh using TempestRemap
+            tempestMesh->Write( out, NcFile::Netcdf4 );
+            file_written = true;
+        }
+        delete remapper;  // cleanup
     }
-    else
-    {
 #endif
 
+    if( !file_written )
+    {
         if( have_sets )
             result = gMB->write_file( out.c_str(), format, write_options.c_str(), &set_list[0], set_list.size() );
         else
@@ -922,10 +952,7 @@ int main( int argc, char* argv[] )
 #endif
             return WRITE_ERROR;
         }
-#ifdef MOAB_HAVE_TEMPESTREMAP
     }
-    delete remapper;
-#endif
 
     if( !proc_id ) std::cerr << "Wrote \"" << out << "\"" << std::endl;
     if( print_times && !proc_id ) write_times( std::cout );
@@ -1020,7 +1047,10 @@ static void print_time( int clk_per_sec, const char* prefix, clock_t ticks, std:
     clock_t centi   = ticks % 100;
     clock_t seconds = ticks / 100;
     stream << prefix;
-    if( seconds < 120 ) { stream << ( ticks / 100 ) << "." << centi << "s" << std::endl; }
+    if( seconds < 120 )
+    {
+        stream << ( ticks / 100 ) << "." << centi << "s" << std::endl;
+    }
     else
     {
         clock_t minutes = ( seconds / 60 ) % 60;
