@@ -10,8 +10,9 @@
 #include "MBTagConventions.hpp"
 #include "moab/Range.hpp"
 
-moab::ErrorCode make_tris_from_quad( moab::Interface* MBI, moab::EntityHandle quad, /* input  */
-                                     moab::EntityHandle& tri0,                      /* output */
+moab::ErrorCode make_tris_from_quad( moab::Interface* MBI,
+                                     moab::EntityHandle quad,  /* input  */
+                                     moab::EntityHandle& tri0, /* output */
                                      moab::EntityHandle& tri1 /* output */ );
 
 moab::ErrorCode make_tris_from_quads( moab::Interface* MBI, const moab::Range& quads, moab::Range& tris );
