@@ -65,19 +65,41 @@ void print_usage()
 
 #ifdef MOAB_HAVE_HDF5
 
-ErrorCode get_file_options( int argc, char** argv, int nprocs, int rank, std::vector< std::string >& meshFiles,
-                            Coupler::Method& method, std::string& interpTag, std::string& gNormTag,
-                            std::string& ssNormTag, std::vector< const char* >& ssTagNames,
-                            std::vector< const char* >& ssTagValues, std::string& readOpts, std::string& outFile,
-                            std::string& writeOpts, std::string& dbgFile, bool& help, double& epsilon );
+ErrorCode get_file_options( int argc,
+                            char** argv,
+                            int nprocs,
+                            int rank,
+                            std::vector< std::string >& meshFiles,
+                            Coupler::Method& method,
+                            std::string& interpTag,
+                            std::string& gNormTag,
+                            std::string& ssNormTag,
+                            std::vector< const char* >& ssTagNames,
+                            std::vector< const char* >& ssTagValues,
+                            std::string& readOpts,
+                            std::string& outFile,
+                            std::string& writeOpts,
+                            std::string& dbgFile,
+                            bool& help,
+                            double& epsilon );
 
 ErrorCode report_iface_ents( Interface* mbImpl, std::vector< ParallelComm* >& pcs, bool print_results );
 
-ErrorCode test_interpolation( Interface* mbImpl, Coupler::Method method, std::string& interpTag, std::string& gNormTag,
-                              std::string& ssNormTag, std::vector< const char* >& ssTagNames,
-                              std::vector< const char* >& ssTagValues, EntityHandle* roots,
-                              std::vector< ParallelComm* >& pcs, double& instant_time, double& pointloc_time,
-                              double& interp_time, double& gnorm_time, double& ssnorm_time, double& toler );
+ErrorCode test_interpolation( Interface* mbImpl,
+                              Coupler::Method method,
+                              std::string& interpTag,
+                              std::string& gNormTag,
+                              std::string& ssNormTag,
+                              std::vector< const char* >& ssTagNames,
+                              std::vector< const char* >& ssTagValues,
+                              EntityHandle* roots,
+                              std::vector< ParallelComm* >& pcs,
+                              double& instant_time,
+                              double& pointloc_time,
+                              double& interp_time,
+                              double& gnorm_time,
+                              double& ssnorm_time,
+                              double& toler );
 
 void reduceMax( double& v )
 {
@@ -257,20 +279,32 @@ bool check_for_flag( const char* str )
 }
 
 // get_file_options() function with added possibilities for mbcoupler_test.
-ErrorCode get_file_options( int argc, char** argv, int nprocs, int rank, std::vector< std::string >& meshFiles,
-                            Coupler::Method& method, std::string& interpTag, std::string& gNormTag,
-                            std::string& ssNormTag, std::vector< const char* >& ssTagNames,
-                            std::vector< const char* >& ssTagValues, std::string& readOpts, std::string& outFile,
-                            std::string& writeOpts, std::string& dbgFile, bool& help, double& epsilon )
+ErrorCode get_file_options( int argc,
+                            char** argv,
+                            int nprocs,
+                            int rank,
+                            std::vector< std::string >& meshFiles,
+                            Coupler::Method& method,
+                            std::string& interpTag,
+                            std::string& gNormTag,
+                            std::string& ssNormTag,
+                            std::vector< const char* >& ssTagNames,
+                            std::vector< const char* >& ssTagValues,
+                            std::string& readOpts,
+                            std::string& outFile,
+                            std::string& writeOpts,
+                            std::string& dbgFile,
+                            bool& help,
+                            double& epsilon )
 {
     // Initialize some of the outputs to null values indicating not present
     // in the argument list.
     gNormTag                   = "";
     ssNormTag                  = "";
     readOpts                   = ( nprocs > 1 ? "PARALLEL=READ_PART;PARTITION=PARALLEL_PARTITION;PARTITION_DISTRIBUTE;"
-                              "PARALLEL_RESOLVE_SHARED_ENTS;PARALLEL_GHOSTS=3.0.1;CPUTIME"
+                                                "PARALLEL_RESOLVE_SHARED_ENTS;PARALLEL_GHOSTS=3.0.1;CPUTIME"
                                               : "PARALLEL=READ_PART;PARTITION=PARALLEL_PARTITION;PARTITION_DISTRIBUTE;"
-                              "PARALLEL_RESOLVE_SHARED_ENTS;CPUTIME" );
+                                                "PARALLEL_RESOLVE_SHARED_ENTS;CPUTIME" );
     outFile                    = "";
     writeOpts                  = ( nprocs > 1 ? "PARALLEL=WRITE_PART;CPUTIME" : "" );
     dbgFile                    = "";
@@ -487,8 +521,8 @@ ErrorCode get_file_options( int argc, char** argv, int nprocs, int rank, std::ve
     if( !haveMeshes )
     {
         meshFiles.resize( 2 );
-        meshFiles[0] = std::string( TestDir + "/64bricks_1khex.h5m" );
-        meshFiles[1] = std::string( TestDir + "/64bricks_12ktet.h5m" );
+        meshFiles[0] = std::string( TestDir + "unittest/64bricks_1khex.h5m" );
+        meshFiles[1] = std::string( TestDir + "unittest/64bricks_12ktet.h5m" );
         if( 0 == rank )
             std::cout << "Mesh files not entered; using default files " << meshFiles[0] << " and " << meshFiles[1]
                       << std::endl;
@@ -503,8 +537,10 @@ ErrorCode get_file_options( int argc, char** argv, int nprocs, int rank, std::ve
 #ifdef MOAB_HAVE_HDF5
     if( 1 == argc )
     {
-        if( 0 == rank ) std::cout << "No arguments given; using output file dum.h5m." << std::endl;
-        outFile = "dum.h5m";
+        std::stringstream dfname;
+        dfname << "dum" << nprocs << ".h5m";
+        outFile = dfname.str();
+        if( 0 == rank ) std::cout << "No arguments given; using output file " << outFile << std::endl;
     }
 #endif
 
@@ -513,11 +549,21 @@ ErrorCode get_file_options( int argc, char** argv, int nprocs, int rank, std::ve
 
 // End get_file_options()
 
-ErrorCode test_interpolation( Interface* mbImpl, Coupler::Method method, std::string& interpTag, std::string& gNormTag,
-                              std::string& ssNormTag, std::vector< const char* >& ssTagNames,
-                              std::vector< const char* >& ssTagValues, EntityHandle* roots,
-                              std::vector< ParallelComm* >& pcs, double& instant_time, double& pointloc_time,
-                              double& interp_time, double& gnorm_time, double& ssnorm_time, double& toler )
+ErrorCode test_interpolation( Interface* mbImpl,
+                              Coupler::Method method,
+                              std::string& interpTag,
+                              std::string& gNormTag,
+                              std::string& ssNormTag,
+                              std::vector< const char* >& ssTagNames,
+                              std::vector< const char* >& ssTagValues,
+                              EntityHandle* roots,
+                              std::vector< ParallelComm* >& pcs,
+                              double& instant_time,
+                              double& pointloc_time,
+                              double& interp_time,
+                              double& gnorm_time,
+                              double& ssnorm_time,
+                              double& toler )
 {
     assert( method >= Coupler::CONSTANT && method <= Coupler::SPHERICAL );
 
