@@ -12,6 +12,7 @@
  *
  */
 
+// standard C++ includes
 #include <iostream>
 #include <iomanip>
 #include <cstdlib>
@@ -20,6 +21,7 @@
 #include <sstream>
 #include <cassert>
 
+// MOAB includes
 #include "moab/Core.hpp"
 #include "moab/IntxMesh/IntxUtils.hpp"
 #include "moab/Remapping/TempestRemapper.hpp"
@@ -41,7 +43,7 @@
 
 struct ToolContext
 {
-    moab::Interface* mbcore;
+    moab::Core* mbcore;
 #ifdef MOAB_HAVE_MPI
     moab::ParallelComm* pcomm;
 #endif
@@ -54,6 +56,7 @@ struct ToolContext
     std::vector< int > disc_orders;
     std::vector< std::string > disc_methods;
     std::vector< std::string > doftag_names;
+    std::string fvMethod;
     std::string outFilename;
     std::string intxFilename;
     std::string baselineFile;
@@ -63,25 +66,26 @@ struct ToolContext
     bool verifyWeights;
     bool enforceConvexity;
     int ensureMonotonicity;
-    bool fNoConservation;
-    bool fVolumetric;
     bool rrmGrids;
     bool kdtreeSearch;
-    bool fNoBubble, fInputConcave, fOutputConcave, fCheck;
+    bool fCheck;
+    bool fVolumetric;
+    bool useGnomonicProjection;
+    GenerateOfflineMapAlgorithmOptions mapOptions;
 
 #ifdef MOAB_HAVE_MPI
-    ToolContext( moab::Interface* icore, moab::ParallelComm* p_pcomm )
+    ToolContext( moab::Core* icore, moab::ParallelComm* p_pcomm )
         : mbcore( icore ), pcomm( p_pcomm ), proc_id( pcomm->rank() ), n_procs( pcomm->size() ),
           outputFormatter( std::cout, pcomm->rank(), 0 ),
 #else
-    ToolContext( moab::Interface* icore )
+    ToolContext( moab::Core* icore )
         : mbcore( icore ), proc_id( 0 ), n_procs( 1 ), outputFormatter( std::cout, 0, 0 ),
 #endif
-          blockSize( 5 ), outFilename( "output.exo" ), intxFilename( "" ), baselineFile( "" ),
-          meshType( moab::TempestRemapper::DEFAULT ), computeDual( false ), computeWeights( false ),
-          verifyWeights( false ), enforceConvexity( false ), ensureMonotonicity( 0 ), fNoConservation( false ),
-          fVolumetric( false ), rrmGrids( false ), kdtreeSearch( true ), fNoBubble( true ), fInputConcave( false ),
-          fOutputConcave( false ), fCheck( n_procs > 1 ? false : true )
+          blockSize( 5 ), fvMethod( "none" ), outFilename( "outputFile.nc" ), intxFilename( "intxFile.h5m" ),
+          baselineFile( "" ), meshType( moab::TempestRemapper::DEFAULT ), computeDual( false ), computeWeights( false ),
+          verifyWeights( false ), enforceConvexity( false ), ensureMonotonicity( 0 ), rrmGrids( false ),
+          kdtreeSearch( true ), fCheck( n_procs > 1 ? false : true ), fVolumetric( false ),
+          useGnomonicProjection( false )
     {
         inFilenames.resize( 2 );
         doftag_names.resize( 2 );
@@ -138,9 +142,9 @@ struct ToolContext
         int imeshType                  = 0;
         std::string expectedFName      = "output.exo";
         std::string expectedMethod     = "fv";
+        std::string expectedFVMethod   = "none";
         std::string expectedDofTagName = "GLOBAL_ID";
         int expectedOrder              = 1;
-        bool fBubble                   = false;
 
         if( !proc_id )
         {
@@ -154,54 +158,84 @@ struct ToolContext
                             "Type of mesh (default=CS; Choose from [CS=0, RLL=1, ICO=2, OVERLAP_FILES=3, "
                             "OVERLAP_MEMORY=4, OVERLAP_MOAB=5])",
                             &imeshType );
+
         opts.addOpt< int >( "res,r", "Resolution of the mesh (default=5)", &blockSize );
+
         opts.addOpt< void >( "dual,d", "Output the dual of the mesh (relevant only for ICO mesh type)", &computeDual );
+
         opts.addOpt< std::string >( "file,f", "Output computed mesh or remapping weights to specified filename",
                                     &outFilename );
         opts.addOpt< std::string >(
             "load,l", "Input mesh filenames for source and target meshes. (relevant only when computing weights)",
             &expectedFName );
-        opts.addOpt< void >( "noconserve,c",
-                             "Do not apply conservation to the resultant weights (relevant only "
-                             "when computing weights)",
-                             &fNoConservation );
-        opts.addOpt< void >( "volumetric,v",
-                             "Apply a volumetric projection to compute the weights (relevant only "
-                             "when computing weights)",
-                             &fVolumetric );
+
         opts.addOpt< void >( "advfront,a",
                              "Use the advancing front intersection instead of the Kd-tree based algorithm "
                              "to compute mesh intersections. (relevant only when computing weights)" );
-        opts.addOpt< int >( "monotonic,n", "Ensure monotonicity in the weight generation", &ensureMonotonicity );
-        opts.addOpt< int >( "order,o", "Discretization orders for the source and target solution fields",
-                            &expectedOrder );
-        opts.addOpt< std::string >( "method,m", "Discretization method for the source and target solution fields",
-                                    &expectedMethod );
-        opts.addOpt< std::string >( "global_id,g",
-                                    "Tag name that contains the global DoF IDs for source and target solution fields",
-                                    &expectedDofTagName );
+
+        opts.addOpt< std::string >( "intx,i", "Output TempestRemap intersection mesh filename", &intxFilename );
 
         opts.addOpt< void >( "weights,w",
                              "Compute and output the weights using the overlap mesh (generally "
                              "relevant only for OVERLAP mesh)",
                              &computeWeights );
-        opts.addOpt< std::string >( "intx,i", "Output TempestRemap intersection mesh filename", &intxFilename );
 
-        opts.addOpt< std::string >( "baseline", "Output baseline file", &baselineFile );
+        opts.addOpt< std::string >( "method,m", "Discretization method for the source and target solution fields",
+                                    &expectedMethod );
+
+        opts.addOpt< int >( "order,o", "Discretization orders for the source and target solution fields",
+                            &expectedOrder );
+
+        opts.addOpt< std::string >( "global_id,g",
+                                    "Tag name that contains the global DoF IDs for source and target solution fields",
+                                    &expectedDofTagName );
+
+        opts.addOpt< void >( "noconserve",
+                             "Do not apply conservation to the resultant weights (relevant only "
+                             "when computing weights)",
+                             &mapOptions.fNoConservation );
+
+        opts.addOpt< void >( "volumetric",
+                             "Apply a volumetric projection to compute the weights (relevant only "
+                             "when computing weights)",
+                             &fVolumetric );
+
+        opts.addOpt< int >( "monotonicity", "Ensure monotonicity in the weight generation. Options=[0,1,2,3]",
+                            &ensureMonotonicity );
+
+        opts.addOpt< void >( "gnomonic", "Use Gnomonic plane projections to compute coverage mesh.",
+                             &useGnomonicProjection );
+
+        opts.addOpt< std::string >( "fvmethod",
+                                    "Sub-type method for FV-FV projections (invdist, delaunay, bilin, "
+                                    "intbilin, intbilingb, none. Default: none)",
+                                    &expectedFVMethod );
+
+        opts.addOpt< void >( "enforce_convexity", "check convexity of input meshes to compute mesh intersections",
+                             &enforceConvexity );
+
+        opts.addOpt< void >( "nobubble", "do not use bubble on interior of spectral element nodes",
+                             &mapOptions.fNoBubble );
+
+        opts.addOpt< void >(
+            "sparseconstraints",
+            "Use sparse solver for constraints when we have high-valence (typical with high-res RLL mesh)",
+            &mapOptions.fSparseConstraints );
 
         opts.addOpt< void >( "rrmgrids",
                              "At least one of the meshes is a regionally refined grid (relevant to "
                              "accelerate intersection computation)",
                              &rrmGrids );
+
         opts.addOpt< void >( "checkmap", "Check the generated map for conservation and consistency", &fCheck );
+
         opts.addOpt< void >( "verify",
                              "Verify the accuracy of the maps by projecting analytical functions "
                              "from source to target "
                              "grid by applying the maps",
                              &verifyWeights );
-        opts.addOpt< void >( "enforce_convexity", "check convexity of input meshes to compute mesh intersections",
-                             &enforceConvexity );
-        opts.addOpt< void >( "bubble", "use bubble on interior of spectral element nodes", &fBubble );
+
+        opts.addOpt< std::string >( "baseline", "Output baseline file", &baselineFile );
 
         opts.parseCommandLine( argc, argv );
 
@@ -209,9 +243,6 @@ struct ToolContext
         // algorithm
         kdtreeSearch = opts.numOptSet( "advfront,a" ) == 0;
 
-        // negate the option
-        fNoBubble = !fBubble;
-
         switch( imeshType )
         {
             case 0:
@@ -243,49 +274,72 @@ struct ToolContext
                 break;
         }
 
-        if( meshType > moab::TempestRemapper::ICO )
+        if( meshType > moab::TempestRemapper::ICO )  // compute overlap mesh and maps possibly
         {
             opts.getOptAllArgs( "load,l", inFilenames );
             opts.getOptAllArgs( "order,o", disc_orders );
             opts.getOptAllArgs( "method,m", disc_methods );
             opts.getOptAllArgs( "global_id,i", doftag_names );
 
-            if( disc_orders.size() == 0 )
-            {
-                disc_orders.resize( 2, 1 );
-            }
-
-            if( disc_orders.size() == 1 )
-            {
-                disc_orders.push_back( 1 );
-            }
-
-            if( disc_methods.size() == 0 )
-            {
-                disc_methods.resize( 2, "fv" );
-            }
-
-            if( disc_methods.size() == 1 )
-            {
-                disc_methods.push_back( "fv" );
-            }
-
-            if( doftag_names.size() == 0 )
-            {
-                doftag_names.resize( 2, "GLOBAL_ID" );
-            }
-
-            if( doftag_names.size() == 1 )
-            {
-                doftag_names.push_back( "GLOBAL_ID" );
-            }
-
             assert( inFilenames.size() == 2 );
             assert( disc_orders.size() == 2 );
             assert( disc_methods.size() == 2 );
+            assert( ensureMonotonicity >= 0 && ensureMonotonicity <= 3 );
+
+            // get discretization order parameters
+            if( disc_orders.size() == 0 ) disc_orders.resize( 2, 1 );
+            if( disc_orders.size() == 1 ) disc_orders.push_back( 1 );
+
+            // get discretization method parameters
+            if( disc_methods.size() == 0 ) disc_methods.resize( 2, "fv" );
+            if( disc_methods.size() == 1 ) disc_methods.push_back( "fv" );
+
+            // get DoF tagname parameters
+            if( doftag_names.size() == 0 ) doftag_names.resize( 2, "GLOBAL_ID" );
+            if( doftag_names.size() == 1 ) doftag_names.push_back( "GLOBAL_ID" );
+
+            // for computing maps and overlaps, set discretization orders
+            mapOptions.nPin           = disc_orders[0];
+            mapOptions.nPout          = disc_orders[1];
+            mapOptions.fSourceConcave = false;
+            mapOptions.fTargetConcave = false;
+
+            mapOptions.strMethod = "";
+
+            if( expectedFVMethod != "none" )
+            {
+                mapOptions.strMethod += expectedFVMethod + ";";
+                fvMethod = expectedFVMethod;
+
+                // These FV projection methods are non-conservative; specify it explicitly
+                mapOptions.fNoConservation = true;
+            }
+            switch( ensureMonotonicity )
+            {
+                case 0:
+                    mapOptions.fMonotone = false;
+                    break;
+                case 3:
+                    mapOptions.strMethod += "mono3;";
+                    break;
+                case 2:
+                    mapOptions.strMethod += "mono2;";
+                    break;
+                default:
+                    mapOptions.fMonotone = true;
+            }
+            mapOptions.fNoCorrectAreas = false;
+            mapOptions.fNoCheck        = !fCheck;
+
+            //assert( fVolumetric && fInverseDistanceMap == false );  // both options cannot be active
+            if( fVolumetric ) mapOptions.strMethod += "volumetric;";
         }
 
+        // clear temporary string name
         expectedFName.clear();
+
+        mapOptions.strOutputMapFile = outFilename;
+        mapOptions.strOutputFormat  = "Netcdf4";
     }
 
   private:
@@ -301,11 +355,79 @@ inline double sample_fast_harmonic( double dLon, double dLat );
 inline double sample_constant( double dLon, double dLat );
 inline double sample_stationary_vortex( double dLon, double dLat );
 
+std::string get_file_read_options( ToolContext& ctx, std::string filename )
+{
+    // if running in serial, blank option may suffice in general
+    std::string opts = "";
+    if( ctx.n_procs > 1 )
+    {
+        size_t lastindex      = filename.find_last_of( "." );
+        std::string extension = filename.substr( lastindex + 1, filename.size() );
+        if( extension == "h5m" )
+            return "PARALLEL=READ_PART;PARTITION=PARALLEL_PARTITION;PARALLEL_RESOLVE_SHARED_ENTS;";
+        else if( extension == "nc" )
+        {
+            // set default set of options
+            opts = "PARALLEL=READ_PART;PARTITION_METHOD=RCBZOLTAN;";
+
+            if( ctx.proc_id == 0 )
+            {
+                {
+                    NcFile ncFile( filename.c_str(), NcFile::ReadOnly );
+                    if( !ncFile.is_valid() )
+                        _EXCEPTION1( "Unable to open grid file \"%s\" for reading", filename.c_str() );
+
+                    // Check for dimension names "grid_size", "grid_rank" and "grid_corners"
+                    int iSCRIPFormat = 0, iMPASFormat = 0, iESMFFormat = 0;
+                    for( int i = 0; i < ncFile.num_dims(); i++ )
+                    {
+                        std::string strDimName = ncFile.get_dim( i )->name();
+                        if( strDimName == "grid_size" || strDimName == "grid_corners" || strDimName == "grid_rank" )
+                            iSCRIPFormat++;
+                        if( strDimName == "nodeCount" || strDimName == "elementCount" ||
+                            strDimName == "maxNodePElement" )
+                            iESMFFormat++;
+                        if( strDimName == "nCells" || strDimName == "nEdges" || strDimName == "nVertices" ||
+                            strDimName == "vertexDegree" )
+                            iMPASFormat++;
+                    }
+                    ncFile.close();
+
+                    if( iESMFFormat == 3 )  // Input from a NetCDF ESMF file
+                    {
+                        opts = "PARALLEL=READ_PART;PARTITION_METHOD=RCBZOLTAN;PARALLEL_RESOLVE_SHARED_ENTS;VARIABLE=;";
+                    }
+                    if( iSCRIPFormat == 3 )  // Input from a NetCDF SCRIP file
+                    {
+                        opts = "PARALLEL=READ_PART;PARTITION_METHOD=RCBZOLTAN;";
+                    }
+                    if( iMPASFormat == 4 )  // Input from a NetCDF SCRIP file
+                    {
+                        opts = "PARALLEL=READ_PART;PARTITION_METHOD=RCBZOLTAN;"
+                               "PARALLEL_RESOLVE_SHARED_ENTS;NO_EDGES;NO_MIXED_ELEMENTS;VARIABLE=;";
+                    }
+                }
+            }
+
+#ifdef MOAB_HAVE_MPI
+            int line_size = opts.size();
+            MPI_Bcast( &line_size, 1, MPI_INT, 0, MPI_COMM_WORLD );
+            if( ctx.proc_id != 0 ) opts.resize( line_size );
+            MPI_Bcast( const_cast< char* >( opts.data() ), line_size, MPI_CHAR, 0, MPI_COMM_WORLD );
+#endif
+        }
+        else
+            return "PARALLEL=BCAST_DELETE;PARTITION=TRIVIAL;PARALLEL_RESOLVE_SHARED_ENTS;";
+    }
+    return opts;
+}
+
 int main( int argc, char* argv[] )
 {
     moab::ErrorCode rval;
     NcError error( NcError::verbose_nonfatal );
     std::stringstream sstr;
+    std::string historyStr;
 
     int proc_id = 0, nprocs = 1;
 #ifdef MOAB_HAVE_MPI
@@ -314,13 +436,17 @@ int main( int argc, char* argv[] )
     MPI_Comm_size( MPI_COMM_WORLD, &nprocs );
 #endif
 
-    moab::Interface* mbCore = new( std::nothrow ) moab::Core;
+    moab::Core* mbCore = new( std::nothrow ) moab::Core;
 
     if( NULL == mbCore )
     {
         return 1;
     }
 
+    // Build the history string
+    for( int ia = 0; ia < argc; ++ia )
+        historyStr += std::string( argv[ia] ) + " ";
+
     ToolContext* runCtx;
 #ifdef MOAB_HAVE_MPI
     moab::ParallelComm* pcomm = new moab::ParallelComm( mbCore, MPI_COMM_WORLD, 0 );
@@ -344,7 +470,7 @@ int main( int argc, char* argv[] )
     moab::TempestRemapper remapper( mbCore );
 #endif
     remapper.meshValidate     = true;
-    remapper.constructEdgeMap = false;
+    remapper.constructEdgeMap = true;
     remapper.initialize();
 
     // Default area_method = lHuiller; Options: Girard, GaussQuadrature (if TR is available)
@@ -366,7 +492,7 @@ int main( int argc, char* argv[] )
                                                // TempestOnlineMap.hpp is included in this file, and is part of MOAB
     // Some constant parameters
 
-    const double boxeps = 1e-6;
+    const double boxeps = 1e-1;
 
     if( runCtx->meshType == moab::TempestRemapper::OVERLAP_MEMORY )
     {
@@ -381,7 +507,6 @@ int main( int argc, char* argv[] )
         // Load the meshes and validate
         rval = remapper.ConvertTempestMesh( moab::Remapper::SourceMesh );MB_CHK_ERR( rval );
         rval = remapper.ConvertTempestMesh( moab::Remapper::TargetMesh );MB_CHK_ERR( rval );
-        remapper.SetMeshType( moab::Remapper::OverlapMesh, moab::TempestRemapper::OVERLAP_FILES );
         rval = remapper.ConvertTempestMesh( moab::Remapper::OverlapMesh );MB_CHK_ERR( rval );
         rval = mbCore->write_mesh( "tempest_intersection.h5m", &runCtx->meshsets[2], 1 );MB_CHK_ERR( rval );
 
@@ -471,15 +596,10 @@ int main( int argc, char* argv[] )
             runCtx->timer_push( "compute weights with the Tempest meshes" );
             // Call to generate an offline map with the tempest meshes
             OfflineMap weightMap;
-            int err = GenerateOfflineMapWithMeshes(
-                weightMap, *runCtx->meshes[0], *runCtx->meshes[1], *runCtx->meshes[2], "",
-                "",  // std::string strInputMeta, std::string strOutputMeta,
-                runCtx->disc_methods[0],
-                runCtx->disc_methods[1],                         // std::string strInputType, std::string strOutputType,
-                runCtx->disc_orders[0], runCtx->disc_orders[1],  // int nPin=4, int nPout=4,
-                runCtx->fNoBubble, true,                         // bool fNoBubble = false, bool fCorrectAreas = false,
-                runCtx->ensureMonotonicity                       // int fMonotoneTypeID = 0
-            );
+            int err = GenerateOfflineMapWithMeshes( *runCtx->meshes[0], *runCtx->meshes[1], *runCtx->meshes[2],
+                                                    runCtx->disc_methods[0],  // std::string strInputType
+                                                    runCtx->disc_methods[1],  // std::string strOutputType,
+                                                    runCtx->mapOptions, weightMap );
             runCtx->timer_pop();
 
             std::map< std::string, std::string > mapAttributes;
@@ -501,9 +621,9 @@ int main( int argc, char* argv[] )
 #endif
         // print verbosely about the problem setting
         {
-            moab::Range rintxverts, rintxelems;
-            rval = mbCore->get_entities_by_dimension( runCtx->meshsets[0], 0, rintxverts );MB_CHK_ERR( rval );
-            rval = mbCore->get_entities_by_dimension( runCtx->meshsets[0], 2, rintxelems );MB_CHK_ERR( rval );
+            moab::Range srcverts, srcelems;
+            rval = mbCore->get_entities_by_dimension( runCtx->meshsets[0], 0, srcverts );MB_CHK_ERR( rval );
+            rval = mbCore->get_entities_by_dimension( runCtx->meshsets[0], 2, srcelems );MB_CHK_ERR( rval );
             rval = moab::IntxUtils::fix_degenerate_quads( mbCore, runCtx->meshsets[0] );MB_CHK_ERR( rval );
             if( runCtx->enforceConvexity )
             {
@@ -511,12 +631,12 @@ int main( int argc, char* argv[] )
             }
             rval = areaAdaptor.positive_orientation( mbCore, runCtx->meshsets[0], radius_src );MB_CHK_ERR( rval );
             if( !proc_id )
-                outputFormatter.printf( 0, "The source set contains %lu vertices and %lu elements \n",
-                                        rintxverts.size(), rintxelems.size() );
+                outputFormatter.printf( 0, "The source set contains %lu vertices and %lu elements \n", srcverts.size(),
+                                        srcelems.size() );
 
-            moab::Range bintxverts, bintxelems;
-            rval = mbCore->get_entities_by_dimension( runCtx->meshsets[1], 0, bintxverts );MB_CHK_ERR( rval );
-            rval = mbCore->get_entities_by_dimension( runCtx->meshsets[1], 2, bintxelems );MB_CHK_ERR( rval );
+            moab::Range tgtverts, tgtelems;
+            rval = mbCore->get_entities_by_dimension( runCtx->meshsets[1], 0, tgtverts );MB_CHK_ERR( rval );
+            rval = mbCore->get_entities_by_dimension( runCtx->meshsets[1], 2, tgtelems );MB_CHK_ERR( rval );
             rval = moab::IntxUtils::fix_degenerate_quads( mbCore, runCtx->meshsets[1] );MB_CHK_ERR( rval );
             if( runCtx->enforceConvexity )
             {
@@ -524,14 +644,17 @@ int main( int argc, char* argv[] )
             }
             rval = areaAdaptor.positive_orientation( mbCore, runCtx->meshsets[1], radius_dest );MB_CHK_ERR( rval );
             if( !proc_id )
-                outputFormatter.printf( 0, "The target set contains %lu vertices and %lu elements \n",
-                                        bintxverts.size(), bintxelems.size() );
+                outputFormatter.printf( 0, "The target set contains %lu vertices and %lu elements \n", tgtverts.size(),
+                                        tgtelems.size() );
         }
+        //rval = mbCore->write_file( "source_mesh.h5m", NULL, writeOptions, &runCtx->meshsets[0], 1 );MB_CHK_ERR( rval );
+        //rval = mbCore->write_file( "target_mesh.h5m", NULL, writeOptions, &runCtx->meshsets[1], 1 );MB_CHK_ERR( rval );
 
         // First compute the covering set such that the target elements are fully covered by the
         // lcoal source grid
         runCtx->timer_push( "construct covering set for intersection" );
-        rval = remapper.ConstructCoveringSet( epsrel, 1.0, 1.0, boxeps, runCtx->rrmGrids );MB_CHK_ERR( rval );
+        rval =
+            remapper.ConstructCoveringSet( epsrel, 1.0, 1.0, boxeps, runCtx->rrmGrids, runCtx->useGnomonicProjection );MB_CHK_ERR( rval );
         runCtx->timer_pop();
 
         // Compute intersections with MOAB with either the Kd-tree or the advancing front algorithm
@@ -614,19 +737,12 @@ int main( int argc, char* argv[] )
             runCtx->timer_pop();
 
             runCtx->timer_push( "compute weights with TempestRemap" );
-
             rval = weightMap->GenerateRemappingWeights(
-                runCtx->disc_methods[0],                         // std::string strInputType
-                runCtx->disc_methods[1],                         // std::string strOutputType,
-                runCtx->disc_orders[0], runCtx->disc_orders[1],  // int nPin, int nPout,
-                runCtx->fNoBubble,                               // bool fNoBubble
-                runCtx->ensureMonotonicity,                      // int fMonotoneTypeID,
-                runCtx->fVolumetric, runCtx->fNoConservation,    // bool fVolumetric, bool fNoConservation,
-                !runCtx->fCheck,                                 //  bool fNoCheck,
-                runCtx->doftag_names[0],                         // std::string source_tag_name
-                runCtx->doftag_names[1],                         // std::string target_tag_name,
-                runCtx->fInputConcave,                           // bool fInputConcave
-                runCtx->fOutputConcave                           // bool fOutputConcave
+                runCtx->disc_methods[0],  // std::string strInputType
+                runCtx->disc_methods[1],  // std::string strOutputType,
+                runCtx->mapOptions,       // const GenerateOfflineMapAlgorithmOptions& options
+                runCtx->doftag_names[0],  // const std::string& source_tag_name
+                runCtx->doftag_names[1]   // const std::string& target_tag_name
             );MB_CHK_ERR( rval );
             runCtx->timer_pop();
 
@@ -642,37 +758,26 @@ int main( int argc, char* argv[] )
 
             if( runCtx->outFilename.size() )
             {
+                std::map< std::string, std::string > attrMap;
+                attrMap["MOABversion"]   = std::string( MOAB_VERSION );
+                attrMap["Title"]         = "MOAB-TempestRemap (mbtempest) Offline Regridding Weight Generator";
+                attrMap["normalization"] = "ovarea";
+                attrMap["remap_options"] = runCtx->mapOptions.strMethod;
+                attrMap["domain_a"]      = runCtx->inFilenames[0];
+                attrMap["domain_b"]      = runCtx->inFilenames[1];
+                attrMap["domain_aUb"]    = runCtx->intxFilename;
+                attrMap["map_aPb"]       = runCtx->outFilename;
+                attrMap["methodorder_a"] = runCtx->disc_methods[0] + ":" + std::to_string( runCtx->disc_orders[0] ) +
+                                           ":" + std::string( runCtx->doftag_names[0] );
+                attrMap["concave_a"]     = runCtx->mapOptions.fSourceConcave ? "true" : "false";
+                attrMap["methodorder_b"] = runCtx->disc_methods[1] + ":" + std::to_string( runCtx->disc_orders[1] ) +
+                                           ":" + std::string( runCtx->doftag_names[1] );
+                attrMap["concave_b"] = runCtx->mapOptions.fTargetConcave ? "true" : "false";
+                attrMap["bubble"]    = runCtx->mapOptions.fNoBubble ? "false" : "true";
+                attrMap["history"]   = historyStr;
+
                 // Write the map file to disk in parallel using either HDF5 or SCRIP interface
-                rval = weightMap->WriteParallelMap( runCtx->outFilename.c_str() );MB_CHK_ERR( rval );
-
-                // Write out the metadata information for the map file
-                if( proc_id == 0 )
-                {
-                    size_t lastindex = runCtx->outFilename.find_last_of( "." );
-                    sstr.str( "" );
-                    sstr << runCtx->outFilename.substr( 0, lastindex ) << ".meta";
-
-                    std::ofstream metafile( sstr.str() );
-                    metafile << "Generator = MOAB-TempestRemap (mbtempest) Offline Regridding "
-                                "Weight Generator"
-                             << std::endl;
-                    metafile << "domain_a = " << runCtx->inFilenames[0] << std::endl;
-                    metafile << "domain_b = " << runCtx->inFilenames[1] << std::endl;
-                    metafile << "domain_aNb = "
-                             << ( runCtx->intxFilename.size() ? runCtx->intxFilename : "outOverlap.h5m" ) << std::endl;
-                    metafile << "map_aPb = " << runCtx->outFilename << std::endl;
-                    metafile << "type_src = " << runCtx->disc_methods[0] << std::endl;
-                    metafile << "np_src = " << runCtx->disc_orders[0] << std::endl;
-                    metafile << "concave_src = " << ( runCtx->fInputConcave ? "true" : "false" ) << std::endl;
-                    metafile << "type_dst = " << runCtx->disc_methods[1] << std::endl;
-                    metafile << "np_dst = " << runCtx->disc_orders[1] << std::endl;
-                    metafile << "concave_dst = " << ( runCtx->fOutputConcave ? "true" : "false" ) << std::endl;
-                    metafile << "mono_type = " << runCtx->ensureMonotonicity << std::endl;
-                    metafile << "bubble = " << ( runCtx->fNoBubble ? "false" : "true" ) << std::endl;
-                    metafile << "version = "
-                             << "MOAB v5.1.0+" << std::endl;
-                    metafile.close();
-                }
+                rval = weightMap->WriteParallelMap( runCtx->outFilename.c_str(), attrMap );MB_CHK_ERR( rval );
             }
 
             if( runCtx->verifyWeights )
@@ -820,17 +925,15 @@ static moab::ErrorCode CreateTempestMesh( ToolContext& ctx, moab::TempestRemappe
         const double radius_src  = 1.0 /*2.0*acos(-1.0)*/;
         const double radius_dest = 1.0 /*2.0*acos(-1.0)*/;
 
-        const char* additional_read_opts = ( ctx.n_procs > 1 ? "NO_SET_CONTAINING_PARENTS;" : "" );
+        //const char* additional_read_opts = ( ctx.n_procs > 1 ? "NO_SET_CONTAINING_PARENTS;" : "" );
+        std::string additional_read_opts_src = get_file_read_options( ctx, ctx.inFilenames[0] );
         std::vector< int > smetadata, tmetadata;
         // Load the source mesh and validate
-        rval = remapper.LoadNativeMesh( ctx.inFilenames[0], ctx.meshsets[0], smetadata, additional_read_opts );MB_CHK_ERR( rval );
+        rval =
+            remapper.LoadNativeMesh( ctx.inFilenames[0], ctx.meshsets[0], smetadata, additional_read_opts_src.c_str() );MB_CHK_ERR( rval );
         if( smetadata.size() )
         {
-            // remapper.SetMeshType( moab::Remapper::SourceMesh,
-            //                       static_cast< moab::TempestRemapper::TempestMeshType >( smetadata[0] ), &smetadata
-            //                       );
-            remapper.SetMeshType( moab::Remapper::SourceMesh,
-                                  static_cast< moab::TempestRemapper::TempestMeshType >( smetadata[0] ) );
+            remapper.SetMeshType( moab::Remapper::SourceMesh, smetadata );
         }
         // Rescale the radius of both to compute the intersection
         rval = moab::IntxUtils::ScaleToRadius( ctx.mbcore, ctx.meshsets[0], radius_src );MB_CHK_ERR( rval );
@@ -838,18 +941,19 @@ static moab::ErrorCode CreateTempestMesh( ToolContext& ctx, moab::TempestRemappe
         ctx.meshes[0] = remapper.GetMesh( moab::Remapper::SourceMesh );
 
         // Load the target mesh and validate
-        rval = remapper.LoadNativeMesh( ctx.inFilenames[1], ctx.meshsets[1], tmetadata, additional_read_opts );MB_CHK_ERR( rval );
+        std::string addititional_read_opts_tgt = get_file_read_options( ctx, ctx.inFilenames[1] );
+        rval = remapper.LoadNativeMesh( ctx.inFilenames[1], ctx.meshsets[1], tmetadata,
+                                        addititional_read_opts_tgt.c_str() );MB_CHK_ERR( rval );
         if( tmetadata.size() )
         {
-            // remapper.SetMeshType( moab::Remapper::TargetMesh,
-            //                       static_cast< moab::TempestRemapper::TempestMeshType >( tmetadata[0] ), &tmetadata
-            //                       );
-            remapper.SetMeshType( moab::Remapper::TargetMesh,
-                                  static_cast< moab::TempestRemapper::TempestMeshType >( tmetadata[0] ) );
+            remapper.SetMeshType( moab::Remapper::TargetMesh, tmetadata );
         }
         rval = moab::IntxUtils::ScaleToRadius( ctx.mbcore, ctx.meshsets[1], radius_dest );MB_CHK_ERR( rval );
         rval = remapper.ConvertMeshToTempest( moab::Remapper::TargetMesh );MB_CHK_ERR( rval );
         ctx.meshes[1] = remapper.GetMesh( moab::Remapper::TargetMesh );
+
+        // ctx.meshes[0]->Write( "SourceMeshMBTR.g" );
+        // ctx.meshes[1]->Write( "TargetMeshMBTR.g" );
     }
     else if( ctx.meshType == moab::TempestRemapper::ICO )
     {
